@@ -2,13 +2,13 @@
 let passing =
   QCheck.Test.make ~count:100 ~long_factor:100
     ~name:"list_rev_is_involutive"
-    QCheck.(list small_int)
+    QCheck.(list int_small)
     (fun l -> List.rev (List.rev l) = l);;
 
 let failing =
   QCheck.Test.make ~count:10
     ~name:"should_fail_sort_id"
-    QCheck.(small_list small_int)
+    QCheck.(list_small nat_small)
     (fun l -> l = List.sort compare l);;
 
 exception Error
@@ -38,19 +38,19 @@ let stats =
 
 
 let neg_test_failing_as_expected =
-  QCheck.Test.make_neg ~name:"neg test pass (failing as expected)" QCheck.small_int (fun i -> i mod 2 = 0)
+  QCheck.Test.make_neg ~name:"neg test pass (failing as expected)" QCheck.int_small (fun i -> i mod 2 = 0)
 
 let neg_test_unexpected_success =
-  QCheck.Test.make_neg ~name:"neg test unexpected success" QCheck.small_int (fun i -> i + i = i * 2)
+  QCheck.Test.make_neg ~name:"neg test unexpected success" QCheck.int_small (fun i -> i + i = i * 2)
 
 let neg_test_error =
-  QCheck.Test.make_neg ~name:"neg fail with error" QCheck.small_int (fun _i -> raise Error)
+  QCheck.Test.make_neg ~name:"neg fail with error" QCheck.nat_small (fun _i -> raise Error)
 
 let fun1 =
   QCheck.Test.make ~count:100 ~long_factor:100
     ~name:"FAIL_pred_map_commute"
     QCheck.(triple
-        (small_list small_int)
+        (list_small nat_small)
         (fun1 Observable.int int)
         (fun1 Observable.int bool))
     (fun (l,QCheck.Fun (_,f), QCheck.Fun (_,p)) ->
@@ -79,7 +79,7 @@ let bad_assume_fail =
        QCheck.assume (x mod 100 = 1);
        true)
 
-let int_gen = QCheck.small_nat (* int *)
+let int_gen = QCheck.nat_small (* int *)
 
 (* Another example (false) property *)
 let prop_foldleft_foldright =
@@ -113,7 +113,7 @@ let prop_foldleft_foldright_uncurry =
 
 let long_shrink =
   let open QCheck in
-  let listgen = list_of_size (Gen.int_range 1000 10000) int in
+  let listgen = list_size (Gen.int_range 1000 10000) int in
   Test.make ~name:"long_shrink" (pair listgen listgen)
     (fun (xs,ys) -> List.rev (xs@ys) = (List.rev xs)@(List.rev ys))
 
@@ -145,7 +145,7 @@ let shrink_int =
 
 let stats_negs =
   QCheck.(Test.make ~count:5_000 ~name:"stats_neg"
-      (add_stat ("dist",fun x -> x) small_signed_int))
+      (add_stat ("dist",fun x -> x) int_small))
     (fun _ -> true)
 
 type tree = Leaf of int | Node of tree * tree
@@ -157,7 +157,7 @@ let gen_tree = QCheck.Gen.(sized @@ fix
   (fun self n -> match n with
     | 0 -> map leaf nat
     | n ->
-      frequency
+      oneof_weighted
         [1, map leaf nat;
          2, map2 node (self (n/2)) (self (n/2))]
     ))
@@ -176,8 +176,8 @@ let passing_tree_rev =
 let stats_tests =
   let open QCheck in
   [
-    Test.make ~name:"stat_display_test_1" ~count:1000 (add_stat ("dist",fun x -> x) small_signed_int) (fun _ -> true);
-    Test.make ~name:"stat_display_test_2" ~count:1000 (add_stat ("dist",fun x -> x) small_nat) (fun _ -> true);
+    Test.make ~name:"stat_display_test_1" ~count:1000 (add_stat ("dist",fun x -> x) int_small) (fun _ -> true);
+    Test.make ~name:"stat_display_test_2" ~count:1000 (add_stat ("dist",fun x -> x) nat_small) (fun _ -> true);
     Test.make ~name:"stat_display_test_3" ~count:1000 (add_stat ("dist",fun x -> x) (int_range (-43643) 435434)) (fun _ -> true);
     Test.make ~name:"stat_display_test_4" ~count:1000 (add_stat ("dist",fun x -> x) (int_range (-40000) 40000)) (fun _ -> true);
     Test.make ~name:"stat_display_test_5" ~count:1000 (add_stat ("dist",fun x -> x) (int_range (-4) 4)) (fun _ -> true);
