@@ -60,6 +60,14 @@ let rec list_split l len acc = match len,l with
   | 0,_ -> List.rev acc, l
   | _,x::xs -> list_split xs (len-1) (x::acc)
 
+let cut_exp_zero s =
+  match String.split_on_char 'e' s with
+  | [signif;exponent] ->
+    (match exponent.[0] with (* int_of_string removes a leading '0' *)
+     | '+' -> Printf.sprintf "%se+%i" signif (int_of_string exponent) (* keep a leading '+' *)
+     | _   -> Printf.sprintf "%se%i" signif (int_of_string exponent)) (* keep a leading '-' *)
+  | _ -> s
+
 exception Failed_precondition
 (* raised if precondition is false *)
 
@@ -344,6 +352,8 @@ module Gen = struct
 
   let map5 = liftA5
 
+  let map_keep_input f x = fun st -> Tree.map (fun a -> a, f a) (x st)
+
   let return = pure
 
   let bind (gen : 'a t) (f : 'a -> ('b t)) : 'b t = fun st ->
@@ -358,17 +368,32 @@ module Gen = struct
   let make_primitive ~(gen : RS.t -> 'a) ~(shrink : 'a -> 'a Seq.t) : 'a t = fun st ->
     Tree.make_primitive shrink (gen st)
 
+  let delay (f : unit -> 'a t) : 'a t = fun st -> f () st
+
+  let add_shrink_invariant (p : 'a -> bool) (gen : 'a t) : 'a t =
+    fun st -> gen st |> Tree.add_shrink_invariant p
+
+  let set_shrink shrink gen =
+    make_primitive
+      ~gen:(fun st -> gen st |> Tree.root)
+      ~shrink
+
+  let no_shrink (gen: 'a t) : 'a t = set_shrink (fun _ -> Seq.empty) gen
+
   let parse_origin (loc : string) (pp : Format.formatter -> 'a -> unit) ~(origin : 'a) ~(low : 'a) ~(high : 'a) : 'a =
     if origin < low then invalid_arg Format.(asprintf "%s: origin value %a is lower than low value %a" loc pp origin pp low)
     else if origin > high then invalid_arg Format.(asprintf "%s: origin value %a is greater than high value %a" loc pp origin pp high)
     else origin
 
-  let small_nat : int t = fun st ->
+  let int_pos_small : int t = fun st ->
     let p = RS.float st 1. in
     let x = if p < 0.75 then RS.int st 10 else RS.int st 100 in
     let shrink a = fun () -> Shrink.int_towards 0 a () in
     Tree.make_primitive shrink x
 
+  let nat_small = int_pos_small
+  let small_nat = nat_small
+
   (** Natural number generator *)
   let nat : int t = fun st ->
     let p = RS.float st 1. in
@@ -381,6 +406,8 @@ module Gen = struct
     let shrink a = fun () -> Shrink.int_towards 0 a () in
     Tree.make_primitive shrink x
 
+  let int_pos_mid = nat
+
   let big_nat : int t = fun st ->
     let p = RS.float st 1. in
     if p < 0.75
@@ -397,16 +424,26 @@ module Gen = struct
     then Tree.Tree (true, Seq.return false_gen)
     else false_gen
 
-  let float : float t = fun st ->
-    let x = exp (RS.float st 15. *. (if RS.bool st then 1. else -1.))
-            *. (if RS.bool st then 1. else -1.)
-    in
+  let float : float t = fun st -> (* switch to [bits64] once lower bound reaches 4.14 *)
+    (* Technically we could write [15] but this is clearer *)
+    let four_bits_mask = 0b1111 in
+    (* Top 4 bits *)
+    let left = Int64.(shift_left (of_int (RS.bits st land four_bits_mask)) 60) in
+    (* Middle 30 bits *)
+    let middle = Int64.(shift_left (of_int (RS.bits st)) 30) in
+    (* Bottom 30 bits *)
+    let right = Int64.of_int (RS.bits st) in
+    let x = Int64.(float_of_bits (logor left (logor middle right))) in
     let shrink a = fun () -> Shrink.float_towards 0. a () in
     Tree.make_primitive shrink x
 
-  let pfloat : float t = float >|= abs_float
+  let float_pos : float t = float >|= abs_float
 
-  let nfloat : float t = pfloat >|= Float.neg
+  let float_neg : float t = float_pos >|= Float.neg
+
+  let pfloat = float_pos
+
+  let nfloat = float_neg
 
   let float_bound_inclusive ?(origin : float = 0.) (bound : float) : float t = fun st ->
     let (low, high) = Float.min_max_num 0. bound in
@@ -445,17 +482,21 @@ module Gen = struct
                    ~origin:(Option.value ~default:(pick_origin_within_range ~low ~high ~goal:0.) origin)
                    ~low
                    ~high in
+    let origin = origin -. low in
     (float_bound_inclusive ~origin (high -. low))
     >|= (fun x -> low +. x)
 
   let (--.) low high = float_range ?origin:None low high
 
-  let exponential (mean : float) =
-    if Float.is_nan mean then invalid_arg "Gen.exponential";
-    let unit_gen = float_bound_inclusive 1.0 in
-    map (fun p -> -. mean *. (log p)) unit_gen
+  let float_exp (mean : float) =
+    if Float.is_nan mean then invalid_arg "Gen.float_exp";
+    let unit_gen = no_shrink (float_bound_inclusive 1.0) in
+    let exp_gen = map (fun p -> -. mean *. (log p)) unit_gen in
+    set_shrink (Shrink.float_towards 0.) exp_gen
     (* See https://en.wikipedia.org/wiki/Relationships_among_probability_distributions *)
 
+  let exponential = float_exp
+
   let neg_int : int t = nat >|= Int.neg
 
   (** [option gen] shrinks towards [None] then towards shrinks of [gen]. *)
@@ -519,6 +560,10 @@ module Gen = struct
     in
     Tree.make_primitive shrink x
 
+  let int_pos = pint ~origin:0
+
+  let int_neg = int_pos >|= (fun n -> - n - 1)
+
   let number_towards = Shrink.number_towards
 
   let int_towards = Shrink.int_towards
@@ -532,15 +577,15 @@ module Gen = struct
   let int : int t =
     bool >>= fun b ->
     if b
-    then pint ~origin:0 >|= (fun n -> - n - 1)
-    else pint ~origin:0
+    then int_pos >|= (fun n -> - n - 1)
+    else int_pos
 
   let int_bound (n : int) : int t =
     if n < 0 then invalid_arg "Gen.int_bound";
     fun st ->
       if n <= (1 lsl 30) - 2
       then Tree.make_primitive (fun a () -> Shrink.int_towards 0 a ()) (RS.int st (n + 1))
-      else Tree.map (fun r -> r mod (n + 1)) (pint st)
+      else Tree.map (fun r -> r mod (n + 1)) (int_pos st)
 
   (** To support ranges wider than [Int.max_int], the general idea is to find the center,
       and generate a random half-difference number as well as whether we add or
@@ -579,26 +624,32 @@ module Gen = struct
   let oneof (l : 'a t list) : 'a t =
     int_bound (List.length l - 1) >>= List.nth l
 
-  let oneofl (l : 'a list) : 'a t =
+  let oneof_list (l : 'a list) : 'a t =
     int_bound (List.length l - 1) >|= List.nth l
 
-  let oneofa (a : 'a array) : 'a t =
+  let oneofl = oneof_list
+
+  let oneof_array (a : 'a array) : 'a t =
     int_bound (Array.length a - 1) >|= Array.get a
 
+  let oneofa = oneof_array
+
   (* NOTE: we keep this alias to not break code that uses [small_int]
      for sizes of strings, arrays, etc. *)
   let small_int = small_nat
 
-  let small_signed_int : int t = fun st ->
+  let int_small : int t = fun st ->
     if RS.bool st
-    then small_nat st
-    else (small_nat >|= Int.neg) st
+    then nat_small st
+    else (nat_small >|= Int.neg) st
+
+  let small_signed_int = int_small
 
   (** Shrink towards the first element of the list *)
-  let frequency (l : (int * 'a t) list) : 'a t =
-    if l = [] then failwith "QCheck2.frequency called with an empty list";
+  let oneof_weighted (l : (int * 'a t) list) : 'a t =
+    if l = [] then failwith "QCheck2.Gen.oneof_weighted called with an empty list";
     let sums = sum_int (List.map fst l) in
-    if sums < 1 then failwith "QCheck2.frequency called with weight sum < 1";
+    if sums < 1 then failwith "QCheck2.Gen.oneof_weighted called with weight sum < 1";
     int_bound (sums - 1)
     >>= fun i ->
     let rec aux acc = function
@@ -607,11 +658,17 @@ module Gen = struct
     in
     aux 0 l
 
-  let frequencyl (l : (int * 'a) list) : 'a t =
-    List.map (fun (weight, value) -> (weight, pure value)) l
-    |> frequency
+  let frequency = oneof_weighted
 
-  let frequencya a = frequencyl (Array.to_list a)
+  let oneof_list_weighted (l : (int * 'a) list) : 'a t =
+    List.map (fun (weight, value) -> (weight, pure value)) l
+    |> oneof_weighted
+
+  let frequencyl = oneof_list_weighted
+
+  let oneof_array_weighted a = oneof_list_weighted (Array.to_list a)
+
+  let frequencya = oneof_array_weighted
 
   let char_range ?(origin : char option) (a : char) (b : char) : char t =
     (int_range ~origin:(Char.code (Option.value ~default:a origin)) (Char.code a) (Char.code b)) >|= Char.chr
@@ -679,25 +736,33 @@ module Gen = struct
 
   let array_repeat (n : int) (gen : 'a t) : 'a array t = list_repeat n gen >|= Array.of_list
 
-  let rec flatten_l (l : 'a t list) : 'a list t =
+  let rec flatten_list (l : 'a t list) : 'a list t =
     match l with
     | [] -> pure []
-    | gen :: gens -> liftA2 List.cons gen (flatten_l gens)
+    | gen :: gens -> liftA2 List.cons gen (flatten_list gens)
 
-  let flatten_a (a : 'a t array) : 'a array t =
-    Array.to_list a |> flatten_l >|= Array.of_list
+  let flatten_l = flatten_list
 
-  let flatten_opt (o : 'a t option) : 'a option t =
+  let flatten_array (a : 'a t array) : 'a array t =
+    Array.to_list a |> flatten_list >|= Array.of_list
+
+  let flatten_a = flatten_array
+
+  let flatten_option (o : 'a t option) : 'a option t =
     match o with
     | None -> pure None
     | Some gen -> option gen
 
-  let flatten_res (res : ('a t, 'e) result) : ('a, 'e) result t =
+  let flatten_opt = flatten_option
+
+  let flatten_result (res : ('a t, 'e) result) : ('a, 'e) result t =
     match res with
     | Ok gen -> gen >|= Result.ok
     | Error e -> pure (Error e)
 
-  let shuffle_a (a : 'a array) : 'a array t = fun st ->
+  let flatten_res = flatten_result
+
+  let shuffle_array (a : 'a array) : 'a array t = fun st ->
     let a = Array.copy a in
     for i = Array.length a - 1 downto 1 do
       let j = RS.int st (i + 1) in
@@ -707,10 +772,14 @@ module Gen = struct
     done;
     Tree.pure a
 
-  let shuffle_l (l : 'a list) : 'a list t =
-    Array.of_list l |> shuffle_a >|= Array.to_list
+  let shuffle_a = shuffle_array
 
-  let shuffle_w_l (l : ((int * 'a) list)) : 'a list t = fun st ->
+  let shuffle_list (l : 'a list) : 'a list t =
+    Array.of_list l |> shuffle_array >|= Array.to_list
+
+  let shuffle_l = shuffle_list
+
+  let shuffle_list_weighted (l : ((int * 'a) list)) : 'a list t = fun st ->
     let sample (w, v) =
       let Tree.Tree (p, _) = float_bound_inclusive 1. st in
       let fl_w = float_of_int w in
@@ -722,6 +791,8 @@ module Gen = struct
     |> List.rev_map snd
     |> Tree.pure
 
+  let shuffle_w_l = shuffle_list_weighted
+
   let pair (g1 : 'a t) (g2 : 'b t) : ('a * 'b) t = liftA2 (fun a b -> (a, b)) g1 g2
 
   let triple (g1 : 'a t) (g2 : 'b t) (g3 : 'c t) : ('a * 'b * 'c) t = (fun a b c -> (a, b, c)) <$> g1 <*> g2 <*> g3
@@ -773,14 +844,16 @@ module Gen = struct
     (* Put alphabet first for shrinking *)
     List.flatten [lower_alphabet; before_lower_alphabet; after_lower_alphabet; newline]
 
-  let printable : char t =
+  let char_printable : char t =
     int_range ~origin:0 0 (List.length printable_chars - 1)
     >|= List.nth printable_chars
+  let printable = char_printable
 
-  let numeral : char t =
+  let char_numeral : char t =
     let zero = 48 in
     let nine = 57 in
     int_range ~origin:zero zero nine >|= char_of_int
+  let numeral = char_numeral
 
   let bytes_size ?(gen = char) (size : int t) : bytes t = fun st ->
     let open Tree in
@@ -807,9 +880,13 @@ module Gen = struct
     in
     Tree (bytes, shrink)
 
+  let bytes_size_of size gen : bytes t = bytes_size ~gen size
+
   let string_size ?(gen = char) (size : int t) : string t =
     bytes_size ~gen size >|= Bytes.unsafe_to_string
 
+  let string_size_of size gen : string t = string_size ~gen size
+
   let bytes_of_char_list cs =
     let b = Buffer.create (List.length cs) in
     List.iter (fun c -> Buffer.add_char b c) cs;
@@ -821,11 +898,11 @@ module Gen = struct
 
   let bytes_of gen = list gen >|= bytes_of_char_list
 
-  let bytes_printable = list printable >|= bytes_of_char_list
+  let bytes_printable = list char_printable >|= bytes_of_char_list
 
-  let bytes_small = list_ignore_size_tree small_nat char >|= bytes_of_char_list
+  let bytes_small = list_ignore_size_tree nat_small char >|= bytes_of_char_list
 
-  let bytes_small_of gen = list_ignore_size_tree small_nat gen >|= bytes_of_char_list
+  let bytes_small_of gen = list_ignore_size_tree nat_small gen >|= bytes_of_char_list
 
   let string_of_char_list cs =
     let b = Buffer.create (List.length cs) in
@@ -838,17 +915,21 @@ module Gen = struct
 
   let string_of gen = list gen >|= string_of_char_list
 
-  let string_printable = list printable >|= string_of_char_list
+  let string_printable = list char_printable >|= string_of_char_list
 
-  let string_small = list_ignore_size_tree small_nat char >|= string_of_char_list
+  let string_small = list_ignore_size_tree nat_small char >|= string_of_char_list
 
-  let string_small_of gen = list_ignore_size_tree small_nat gen >|= string_of_char_list
+  let string_small_of gen = list_ignore_size_tree nat_small gen >|= string_of_char_list
 
   let small_string ?(gen=char) = string_small_of gen
 
-  let small_list gen = list_ignore_size_tree small_nat gen
+  let list_small gen = list_ignore_size_tree nat_small gen
 
-  let small_array gen = list_ignore_size_tree small_nat gen >|= Array.of_list
+  let small_list = list_small
+
+  let array_small gen = list_ignore_size_tree nat_small gen >|= Array.of_list
+
+  let small_array = array_small
 
   let join (gen : 'a t t) : 'a t = gen >>= Fun.id
 
@@ -861,8 +942,9 @@ module Gen = struct
 
   let int_pos_corners = [0; 1; 2; max_int]
 
-  let int_corners = int_pos_corners @ [min_int]
+  let int_corners = int_pos_corners @ [min_int; -2; -1]
 
+  let int_small_corners () : int t = graft_corners int_small int_corners ()
   let small_int_corners () : int t = graft_corners nat int_pos_corners ()
 
   (* sized, fix *)
@@ -885,18 +967,6 @@ module Gen = struct
   let generate_tree ?(rand=RS.make_self_init()) (gen : 'a t) : 'a Tree.t =
     gen rand
 
-  let delay (f : unit -> 'a t) : 'a t = fun st -> f () st
-
-  let add_shrink_invariant (p : 'a -> bool) (gen : 'a t) : 'a t =
-    fun st -> gen st |> Tree.add_shrink_invariant p
-
-  let set_shrink shrink gen =
-    make_primitive
-      ~gen:(fun st -> gen st |> Tree.root)
-      ~shrink
-
-  let no_shrink (gen: 'a t) : 'a t = set_shrink (fun _ -> Seq.empty) gen
-
   let (let+) = (>|=)
 
   let (and+) = pair
@@ -917,7 +987,12 @@ module Print = struct
 
   let bool = string_of_bool
 
-  let float = string_of_float
+  let float f = (* Workaround for Windows and macOS to print negative nans consistently as "-nan" *)
+    if Float.is_nan f && Float.sign_bit f
+    then "-nan"
+    else if Sys.win32 (* Windows workaround to avoid leading exponent zero such as "-1.00001604579e-010" *)
+    then string_of_float f |> cut_exp_zero
+    else string_of_float f
 
   let string s = Printf.sprintf "%S" s
 
@@ -2013,10 +2088,10 @@ module Test = struct
   let pp_print_test_fail name out l =
     let rec pp_list out = function
       | [] -> ()
-      | [x] -> Format.fprintf out "%s@," x
+      | [x] -> Format.pp_print_string out x
       | x :: y -> Format.fprintf out "%s@,%a" x pp_list y
     in
-    Format.fprintf out "@[test `%s`@ failed on ≥ %d cases:@ @[<v>%a@]@]"
+    Format.fprintf out "@[test `%s`@ failed on ≥ %d cases:@ @[<v>%a@]@]@,"
       name (List.length l) pp_list l
 
   let asprintf fmt =
@@ -2034,8 +2109,17 @@ module Test = struct
 
   let print_collect c =
     let out = Buffer.create 64 in
-    Hashtbl.iter
-      (fun case num -> Printf.bprintf out "%s: %d cases\n" case num) c;
+    let total,lab_len =
+      Hashtbl.fold
+        (fun case num (total,lab_len) -> (total+num, max lab_len (String.length case))) c (0,0) in
+    let sorted_cases = (* reverse compare yields decreasing order *)
+      Hashtbl.to_seq c |> List.of_seq |> List.sort (fun (_,n1) (_,n2) -> Int.compare n2 n1) in
+    List.iter
+      (fun (case,num) ->
+         let percentage = 100. *. (float num) /. (float total) in (* Workaround for Windows/Unix difference: *)
+         let percentage = (Float.round (10. *. percentage)) /. 10. in (* 100. *. 7525. /. 10000. -> 75.2 or 75.3 *)
+         let perc_str = Printf.sprintf "(%.1f%%)" percentage in
+         Printf.bprintf out " %-*s %6d cases %8s\n" (1+lab_len) (case ^ ":") num perc_str) sorted_cases;
     Buffer.contents out
 
   let stat_max_lines = 20 (* maximum number of lines for a histogram *)
@@ -2111,10 +2195,6 @@ module Test = struct
     (* print entries of the table, sorted by increasing index *)
     let out = Buffer.create 128 in
     (* Windows workaround to avoid annoying exponent zero such as "1.859e+018" *)
-    let cut_exp_zero s =
-      match String.split_on_char '+' s with
-      | [signif;exponent] -> Printf.sprintf "%s+%i" signif (int_of_string exponent)
-      | _ -> failwith "cut_exp_zero failed to parse scientific notation " ^ s in
     let fmt_float f =
       if f > 1e7 || f < -1e7 then cut_exp_zero (Printf.sprintf "%.3e" f) else Printf.sprintf "%.2f" f in
     Printf.bprintf out "stats %s:\n" name;
