@@ -136,7 +136,7 @@ module Raw = struct
     if verbose then (
       print.info "%slaw %s: %d relevant cases (%d total)\n"
         reset_line name (R.get_count result) (R.get_count_gen result);
-      begin match QCheck2.TestResult.collect result with
+      begin match QCheck2.TestResult.get_collect result with
         | None -> ()
         | Some tbl ->
           print_string (QCheck2.Test.print_collect tbl)
@@ -308,6 +308,7 @@ let callback ~size ~out ~verbose ~colors c name cell r =
     else QCheck2.TestResult.is_failed r in
   let color = if pass then `Green else `Red in
   if verbose then (
+    (* print final test status line regardless of rate-limiting for responsive user feedback *)
     Printf.fprintf out "%s[%a] %a %s\n%!"
       (if colors then Color.reset_line else "\n")
       (Color.pp_str_c ~bold:true ~colors color) (if pass then "✓" else "✗")
@@ -338,7 +339,7 @@ let print_messages ~colors out cell l =
   )
 
 let print_success ~colors out cell r =
-  begin match QCheck2.TestResult.collect r with
+  begin match QCheck2.TestResult.get_collect r with
     | None -> ()
     | Some tbl ->
       Printf.fprintf out
@@ -351,16 +352,16 @@ let print_success ~colors out cell r =
          "\n!!! %a %s\n\nWarning for test %s:\n\n%s%!"
         (Color.pp_str_c ~colors `Yellow) "Warning" (String.make 68 '!')
         (QCheck2.Test.get_name cell) msg)
-    (QCheck2.TestResult.warnings r);
+    (QCheck2.TestResult.get_warnings r);
 
-  if QCheck2.TestResult.stats r <> []  then
+  if QCheck2.TestResult.get_stats r <> []  then
      Printf.fprintf out
        "\n+++ %a %s\n%!"
        (Color.pp_str_c ~colors `Blue) ("Stats for " ^ QCheck2.Test.get_name cell)
        (String.make 56 '+');
   List.iter
     (fun st -> Printf.fprintf out "\n%s%!" (QCheck2.Test.print_stat st))
-    (QCheck2.TestResult.stats r);
+    (QCheck2.TestResult.get_stats r);
   ()
 
 let print_fail ~colors out cell c_ex =
@@ -415,10 +416,12 @@ let run_tests
       start; expected; gen = 0;
       passed = 0; failed = 0; errored = 0;
     } in
-    if verbose then
+    if verbose then (
+      (* print initial test status line regardless of rate-limiting for responsive user feedback *)
+      last_msg := Unix.gettimeofday();
       Printf.fprintf out "%s[ ] %a %s%!"
         (if colors then Color.reset_line else "")
-        (pp_counter ~size) c (T.get_name cell);
+        (pp_counter ~size) c (T.get_name cell));
     let r = QCheck2.Test.check_cell ~long ~rand
         ~handler:(handler ~colors ~debug_shrink ~debug_shrink_list
                     ~size ~out ~verbose c).handler
