@@ -24,7 +24,7 @@ module IntTree = struct
                         (fun self n -> match n with
                            | 0 -> map leaf nat
                            | n ->
-                             frequency
+                             oneof_weighted
                                [1, map leaf nat;
                                 2, map2 node (self (n/2)) (self (n/2))]
                         ))
@@ -45,15 +45,15 @@ module Overall = struct
   let passing =
     Test.make ~name:"list_rev_is_involutive" ~count:100 ~long_factor:100
       ~print:Print.(list int)
-      Gen.(list small_int) (fun l -> List.rev (List.rev l) = l)
+      Gen.(list int_small) (fun l -> List.rev (List.rev l) = l)
 
   let failing =
     Test.make ~name:"should_fail_sort_id" ~count:10 ~print:Print.(list int)
-      Gen.(small_list small_int) (fun l -> l = List.sort compare l)
+      Gen.(list_small nat_small) (fun l -> l = List.sort compare l)
 
   let max_fail =
     Test.make ~name:"max_fail" ~count:1000 ~max_fail:3 ~print:Print.(list int)
-      Gen.(list small_nat) (fun l -> l = List.rev l)
+      Gen.(list nat_small) (fun l -> l = List.rev l)
 
   exception Error
 
@@ -76,7 +76,7 @@ module Overall = struct
 
   let retries =
     Test.make ~name:"with shrinking retries" ~retries:10 ~print:Print.int
-      Gen.small_nat (fun i -> Printf.printf "%i %!" i; i mod 3 <> 1)
+      Gen.nat_small (fun i -> Printf.printf "%i %!" i; i mod 3 <> 1)
 
   let bad_assume_warn =
     Test.make ~name:"WARN_unlikely_precond" ~count:2_000 ~print:Print.int
@@ -106,20 +106,20 @@ module Overall = struct
       (fun _i -> false)
 
   let neg_test_fail_as_expected =
-    Test.make_neg ~name:"all ints are even" ~print:Print.int Gen.small_int (fun i -> i mod 2 = 0)
+    Test.make_neg ~name:"all ints are even" ~print:Print.int Gen.int_small (fun i -> i mod 2 = 0)
 
   let neg_test_unexpected_success =
-    Test.make_neg ~name:"int double" ~print:Print.int Gen.small_int (fun i -> i + i = i * 2)
+    Test.make_neg ~name:"int double" ~print:Print.int Gen.int_small (fun i -> i + i = i * 2)
 
   let neg_test_fail_with_shrinking =
     Test.make_neg ~name:"list rev concat" ~print:Print.(pair (list int) (list int))
-      Gen.(pair (list small_int) (list small_int)) (fun (is,js) -> (List.rev is)@(List.rev js) = List.rev (is@js))
+      Gen.(pair (list int_small) (list int_small)) (fun (is,js) -> (List.rev is)@(List.rev js) = List.rev (is@js))
 
   let pos_test_fails_with_error =
-    Test.make ~name:"pos fail with error" ~print:Print.int Gen.small_int (fun _i -> raise Error)
+    Test.make ~name:"pos fail with error" ~print:Print.int Gen.nat_small (fun _i -> raise Error)
 
   let neg_test_fail_with_error =
-    Test.make_neg ~name:"neg fail with error" ~print:Print.int Gen.small_int (fun _i -> raise Error)
+    Test.make_neg ~name:"neg fail with error" ~print:Print.int Gen.nat_small (fun _i -> raise Error)
 
   (* [apply_n f x n] computes f(f(...f(x))) with n applications of f *)
   let rec apply_n f x n =
@@ -132,7 +132,7 @@ module Overall = struct
     let sleep_time = 0.175 in
     let count = ref 0 in
     Test.make ~count:10 ~name:"bad function reproducability"
-      Gen.(triple small_int (fun1 Observable.int small_int) small_int)
+      Gen.(triple nat_small (fun1 Observable.int nat_small) nat_small)
       (fun (i,f,j) ->
          incr count;
          Printf.printf "(%i,fun,%i)%s%!" i j (if !count mod 10 = 0 then "\n" else " ");
@@ -186,13 +186,17 @@ module Generator = struct
     Test.make ~name:"char has right range'" ~count:1000 ~print:Print.char
       Gen.char (fun c -> '\000' <= c && c <= '\255')
 
-  let printable_test =
-    Test.make ~name:"printable has right range" ~count:1000 ~print:Print.char
-      Gen.printable (fun c -> c = '\n' || 32 <= Char.code c && Char.code c <= 126)
+  let char_range_test =
+    Test.make ~name:"char_range 'a' 'z' has right range" ~count:1000 ~print:Print.char
+      (Gen.char_range 'a' 'z') (fun c -> 'a' <= c && c <= 'z')
 
-  let numeral_test =
-    Test.make ~name:"numeral has right range" ~count:1000 ~print:Print.char
-      Gen.numeral (fun c -> '0' <= c && c <= '9')
+  let char_printable_test =
+    Test.make ~name:"char_printable has right range" ~count:1000 ~print:Print.char
+      Gen.char_printable (fun c -> c = '\n' || 32 <= Char.code c && Char.code c <= 126)
+
+  let char_numeral_test =
+    Test.make ~name:"char_numeral has right range" ~count:1000 ~print:Print.char
+      Gen.char_numeral (fun c -> '0' <= c && c <= '9')
 
   let nat_test =
     Test.make ~name:"nat has right range" ~count:1000 ~print:Print.int
@@ -230,17 +234,17 @@ module Generator = struct
 
   let pair_test =
     Test.make ~name:"int pairs - commute over +" ~count:1000 ~print:Print.(pair int int)
-      Gen.(pair small_nat small_nat) (fun (i,j) -> i+j = j+i)
+      Gen.(pair nat_small nat_small) (fun (i,j) -> i+j = j+i)
 
   let triple_test =
     Test.make ~name:"int triples - associative over +" ~count:1000
       ~print:Print.(triple int int int)
-      Gen.(triple small_nat small_nat small_nat) (fun (i,j,k) -> i+(j+k) = (i+j)+k)
+      Gen.(triple nat_small nat_small nat_small) (fun (i,j,k) -> i+(j+k) = (i+j)+k)
 
   let quad_test =
     Test.make ~name:"int quadruples - product of sums" ~count:1000
       ~print:Print.(quad int int int int)
-      Gen.(quad small_nat small_nat small_nat small_nat)
+      Gen.(quad nat_small nat_small nat_small nat_small)
       (fun (h,i,j,k) -> (h+i)*(j+k) = h*j + h*k + i*j + i*k)
 
   let test_tup2 =
@@ -299,7 +303,7 @@ module Generator = struct
 
   let bind_test =
     Test.make ~name:"bind test for ordered pairs" ~count:1000 ~print:Print.(pair int int)
-      Gen.(small_nat >>= fun j -> int_bound j >>= fun i -> return (i,j))
+      Gen.(nat_small >>= fun j -> int_bound j >>= fun i -> return (i,j))
       (fun (i,j) -> i<=j)
 
   let bind_pair_list_length =
@@ -313,18 +317,6 @@ module Generator = struct
       ~print:Print.(list unit)
       Gen.(list unit) (fun l -> let len = List.length l in 0 <= len && len < 10_000)
 
-  let list_repeat_test =
-    Test.make ~name:"list_repeat has constant length" ~count:1000
-      ~print:Print.(pair int (list unit))
-      Gen.(small_nat >>= fun i -> list_repeat i unit >>= fun l -> return (i,l))
-      (fun (i,l) -> List.length l = i)
-
-  let array_repeat_test =
-    Test.make ~name:"array_repeat has constant length" ~count:1000
-      ~print:Print.(pair int (array unit))
-      Gen.(small_nat >>= fun i -> array_repeat i unit >>= fun l -> return (i,l))
-      (fun (i,l) -> Array.length l = i)
-
   let int_option_test =
     Test.make ~name:"int option right range" ~count:1000 ~print:Print.(option int)
       Gen.(option (int_bound 1000))
@@ -349,6 +341,9 @@ module Generator = struct
   let tests = [
     char_dist_issue_23;
     char_test;
+    char_range_test;
+    char_printable_test;
+    char_numeral_test;
     nat_test;
     int_test;
     int32_test;
@@ -369,8 +364,6 @@ module Generator = struct
     bind_test;
     bind_pair_list_length;
     list_test;
-    list_repeat_test;
-    array_repeat_test;
     int_option_test;
     int_string_result_test;
     passing_tree_rev;
@@ -389,7 +382,7 @@ module Shrink = struct
   (* example from issue #59 *)
   let test_fac_issue59 =
     Test.make ~name:"test fac issue59"
-      (Gen.make_primitive ~gen:(fun st -> Gen.generate1 ~rand:st (Gen.small_int_corners ())) ~shrink:(fun _ -> Seq.empty))
+      (Gen.make_primitive ~gen:(fun st -> Gen.generate1 ~rand:st (Gen.int_small_corners ())) ~shrink:(fun _ -> Seq.empty))
       (fun n -> try (fac n) mod n = 0
                 with
                 (*| Stack_overflow   -> false*)
@@ -397,7 +390,7 @@ module Shrink = struct
 
   let big_bound_issue59 =
     Test.make ~name:"big bound issue59" ~print:Print.int
-      (Gen.small_int_corners()) (fun i -> i < 209609)
+      (Gen.int_small_corners()) (fun i -> i < 209609)
 
   let long_shrink =
     let listgen = Gen.(list_size (int_range 1000 10000) int) in
@@ -433,7 +426,7 @@ module Shrink = struct
   (* test from issue #59 *)
   let ints_smaller_209609 =
     Test.make ~name:"ints < 209609" ~print:Print.int
-      (Gen.small_int_corners()) (fun i -> i < 209609)
+      (Gen.int_small_corners()) (fun i -> i < 209609)
 
   let nats_smaller_5001 =
     Test.make ~name:"nat < 5001" ~count:1000 ~print:Print.int
@@ -467,17 +460,121 @@ module Shrink = struct
     Test.make ~name:"float >= -1e10" ~count:1000 ~print:Print.float
       Gen.float (fun f -> f >= -1e10)
 
+  let float_not_nan =
+    Test.make ~name:"float is not nan" ~count:10_000 ~print:Print.float
+      Gen.float (fun f -> not (Float.is_nan f))
+
+  let float_not_infinite =
+    Test.make ~name:"float is not infinity" ~count:10_000 ~print:Print.float
+      Gen.float (fun f -> not (Float.is_infinite f))
+
+  let float_bound_inclusive_1e6_leq_10 =
+    Test.make ~name:"float_bound_inclusive 1e6 <= 10." ~count:1000 ~print:Print.float
+      (Gen.float_bound_inclusive 1e6) (fun f -> f <= 10.)
+
+  let float_bound_inclusive_1e6_leq_pi =
+    Test.make ~name:"float_bound_inclusive 1e6 <= pi" ~count:1000 ~print:Print.float
+      (Gen.float_bound_inclusive 1e6) (fun f -> f <= Float.pi)
+
+  let float_bound_inclusive_1_leq_5em1 =
+    Test.make ~name:"float_bound_inclusive 1. <= 0.5" ~count:1000 ~print:Print.float
+      (Gen.float_bound_inclusive 1.) (fun f -> f <= 0.5)
+
+  let float_bound_inclusive_1_leq_min_float =
+    Test.make ~name:"float_bound_inclusive 1. <= min_float" ~count:1000 ~print:Print.float
+      (Gen.float_bound_inclusive 1.) (fun f -> f <= min_float)
+
+  let float_bound_inclusive_m1_geq_m5em1 =
+    Test.make ~name:"float_bound_inclusive -1. >= -0.5" ~count:1000 ~print:Print.float
+      (Gen.float_bound_inclusive (-1.)) (fun f -> f >= -0.5)
+
+  let float_bound_inclusive_m1e6_geq_mpi =
+    Test.make ~name:"float_bound_inclusive -1e6 >= -.pi" ~count:1000 ~print:Print.float
+      (Gen.float_bound_inclusive (-1e6)) (fun f -> f >= -.Float.pi)
+
+  let float_bound_exclusive_1e6_leq_10 =
+    Test.make ~name:"float_bound_exclusive 1e6 <= 10." ~count:1000 ~print:Print.float
+      (Gen.float_bound_exclusive 1e6) (fun f -> f <= 10.)
+
+  let float_bound_exclusive_1e6_leq_pi =
+    Test.make ~name:"float_bound_exclusive 1e6 <= pi" ~count:1000 ~print:Print.float
+      (Gen.float_bound_exclusive 1e6) (fun f -> f <= Float.pi)
+
+  let float_bound_exclusive_1_leq_5em1 =
+    Test.make ~name:"float_bound_exclusive 1. <= 0.5" ~count:1000 ~print:Print.float
+      (Gen.float_bound_exclusive 1.) (fun f -> f <= 0.5)
+
+  let float_bound_exclusive_1_leq_min_float =
+    Test.make ~name:"float_bound_exclusive 1. <= min_float" ~count:1000 ~print:Print.float
+      (Gen.float_bound_exclusive 1.) (fun f -> f <= min_float)
+
+  let float_bound_exclusive_m1_geq_m5em1 =
+    Test.make ~name:"float_bound_exclusive -1. >= -0.5" ~count:1000 ~print:Print.float
+      (Gen.float_bound_exclusive (-1.)) (fun f -> f >= -0.5)
+
+  let float_bound_exclusive_m1e6_geq_mpi =
+    Test.make ~name:"float_bound_exclusive -1e6 >= -.pi" ~count:1000 ~print:Print.float
+      (Gen.float_bound_exclusive (-1e6)) (fun f -> f >= -.Float.pi)
+
+  let float_range_1_10_leq_pi =
+    Test.make ~name:"float_range 1. 10. <= pi" ~count:1000 ~print:Print.float
+      (Gen.float_range 1. 10.) (fun f -> f <= Float.pi)
+
+  let float_range_m10_10_square_leq_2 =
+    Test.make ~name:"(float_range -10. 10.)^2 <= 2." ~count:1000 ~print:Print.float
+      (Gen.float_range (-10.) 10.) (fun f -> f *. f <= 2.)
+
+  let float_range_m10_m1_geq_mpi =
+    Test.make ~name:"float_range -10. -1. >= -.pi" ~count:1000 ~print:Print.float
+      (Gen.float_range (-10.) (-1.)) (fun f -> f >= -.Float.pi)
+
+  let float_pos_lt_pi =
+    Test.make ~name:"float_pos < Float.pi" ~count:1000 ~print:Print.float
+      Gen.float_pos (fun f -> f < Float.pi)
+
+  let float_pos_not_nan =
+    Test.make ~name:"float_pos is not nan" ~count:10_000 ~print:Print.float
+      Gen.float_pos (fun f -> not (Float.is_nan f))
+
+  let float_pos_not_infinite =
+    Test.make ~name:"float_pos is not infinity" ~count:10_000 ~print:Print.float
+      Gen.float_pos (fun f -> not (Float.is_infinite f))
+
+  let float_neg_gt_mpi =
+    Test.make ~name:"float_neg > Float.pi" ~count:1000 ~print:Print.float
+      Gen.float_neg (fun f -> f > -.Float.pi)
+
+  let float_neg_not_nan =
+    Test.make ~name:"float_neg is not nan" ~count:10_000 ~print:Print.float
+      Gen.float_neg (fun f -> not (Float.is_nan f))
+
+  let float_neg_not_infinite =
+    Test.make ~name:"float_neg is not infinity" ~count:10_000 ~print:Print.float
+      Gen.float_neg (fun f -> not (Float.is_infinite f))
+
+  let float_exp_10_lt_pi =
+    Test.make ~name:"float_exp 10. < Float.pi" ~count:1000 ~print:Print.float
+      (Gen.float_exp 10.) (fun f -> f < Float.pi)
+
+  let float_exp_m10_gt_mpi =
+    Test.make ~name:"float_exp -10. > -. Float.pi" ~count:1000 ~print:Print.float
+      (Gen.float_exp (-10.)) (fun f -> f > -. Float.pi)
+
   let char_is_never_abcdef =
     Test.make ~name:"char never produces 'abcdef'" ~count:1000 ~print:Print.char
       Gen.char (fun c -> not (List.mem c ['a';'b';'c';'d';'e';'f']))
 
-  let printable_is_never_sign = (* should shrink towards '!' with lowest ascii code 33 *)
-    Test.make ~name:"printable never produces '!\"#$%&'" ~count:1000 ~print:Print.char
-      Gen.printable (fun c -> not (List.mem c ['!';'"';'#';'$';'%';'&']))
+  let char_range_is_never_abc =
+    Test.make ~name:"char never 'abc'" ~count:1000 ~print:Print.char
+      (Gen.char_range 'a' 'z') (fun c -> not (c < 'c'))
 
-  let numeral_is_never_less_5 =
-    Test.make ~name:"printable never produces less than '5" ~count:1000 ~print:Print.char
-      Gen.numeral (fun c -> c >= '5')
+  let char_printable_is_never_sign = (* should shrink towards '!' with lowest ascii code 33 *)
+    Test.make ~name:"char_printable never produces '!\"#$%&'" ~count:1000 ~print:Print.char
+      Gen.char_printable (fun c -> not (List.mem c ['!';'"';'#';'$';'%';'&']))
+
+  let char_numeral_is_never_less_5 =
+    Test.make ~name:"char_numeral never produces less than '5'" ~count:1000 ~print:Print.char
+      Gen.char_numeral (fun c -> c >= '5')
 
   let bytes_are_empty =
     Test.make ~name:"bytes are empty" ~count:1000 ~print:Print.bytes
@@ -524,7 +621,7 @@ module Shrink = struct
   (* test from issue #167 *)
   let pair_diff_issue_64 =
     Test.make ~name:"pairs have different components" ~print:Print.(pair int int)
-      Gen.(pair small_int small_int) (fun (i,j) -> i<>j)
+      Gen.(pair nat_small nat_small) (fun (i,j) -> i<>j)
 
   let pair_same =
     Test.make ~name:"pairs have same components" ~print:Print.(pair int int)
@@ -540,29 +637,29 @@ module Shrink = struct
 
   let pair_ordered =
     Test.make ~name:"pairs are ordered" ~print:Print.(pair int int)
-      Gen.(pair (pint ~origin:0) (pint ~origin:0)) (fun (i,j) -> i<=j)
+      Gen.(pair int_pos int_pos) (fun (i,j) -> i<=j)
 
   let pair_ordered_rev =
     Test.make ~name:"pairs are ordered reversely" ~print:Print.(pair int int)
-      Gen.(pair (pint ~origin:0) (pint ~origin:0)) (fun (i,j) -> i>=j)
+      Gen.(pair int_pos int_pos) (fun (i,j) -> i>=j)
 
   let pair_sum_lt_128 =
     Test.make ~name:"pairs sum to less than 128" ~print:Print.(pair int int)
-      Gen.(pair (pint ~origin:0) (pint ~origin:0)) (fun (i,j) -> i+j<128)
+      Gen.(pair int_pos int_pos) (fun (i,j) -> i+j<128)
 
   let pair_lists_rev_concat =
     Test.make ~name:"pairs lists rev concat" ~print:Print.(pair (list int) (list int))
-      Gen.(pair (list (pint ~origin:0)) (list (pint ~origin:0)))
+      Gen.(pair (list int_pos) (list int_pos))
       (fun (xs,ys) -> List.rev (xs@ys) = (List.rev xs)@(List.rev ys))
 
   let pair_lists_no_overlap =
     Test.make ~name:"pairs lists no overlap" ~print:Print.(pair (list int) (list int))
-      Gen.(pair (list small_nat) (list small_nat))
+      Gen.(pair (list nat_small) (list nat_small))
       (fun (xs,ys) -> List.for_all (fun x -> not (List.mem x ys)) xs)
 
   let triple_diff =
     Test.make ~name:"triples have pair-wise different components" ~print:Print.(triple int int int)
-      Gen.(triple small_int small_int small_int) (fun (i,j,k) -> i<>j && j<>k)
+      Gen.(triple nat_small nat_small nat_small) (fun (i,j,k) -> i<>j && j<>k)
 
   let triple_same =
     Test.make ~name:"triples have same components" ~print:Print.(triple int int int)
@@ -578,7 +675,7 @@ module Shrink = struct
 
   let quad_diff =
     Test.make ~name:"quadruples have pair-wise different components" ~print:Print.(quad int int int int)
-      Gen.(quad small_int small_int small_int small_int) (fun (h,i,j,k) -> h<>i && i<>j && j<>k)
+      Gen.(quad nat_small nat_small nat_small nat_small) (fun (h,i,j,k) -> h<>i && i<>j && j<>k)
 
   let quad_same =
     Test.make ~name:"quadruples have same components" ~print:Print.(quad int int int int)
@@ -596,61 +693,61 @@ module Shrink = struct
     Test.make
       ~print:Print.(tup2 int int)
       ~name:"forall (a, b) in nat: a < b"
-      Gen.(tup2 small_int small_int)
+      Gen.(tup2 nat_small nat_small)
       (fun (a, b) -> a < b)
 
   let test_tup3 =
     Test.make
       ~print:Print.(tup3 int int int)
       ~name:"forall (a, b, c) in nat: a < b < c"
-      Gen.(tup3 small_int small_int small_int)
+      Gen.(tup3 nat_small nat_small nat_small)
       (fun (a, b, c) -> a < b && b < c)
 
   let test_tup4 =
     Test.make
       ~print:Print.(tup4 int int int int)
       ~name:"forall (a, b, c, d) in nat: a < b < c < d"
-      Gen.(tup4 small_int small_int small_int small_int)
+      Gen.(tup4 nat_small nat_small nat_small nat_small)
       (fun (a, b, c, d) -> a < b && b < c && c < d)
 
   let test_tup5 =
     Test.make
       ~print:Print.(tup5 int int int int int)
       ~name:"forall (a, b, c, d, e) in nat: a < b < c < d < e"
-      Gen.(tup5 small_int small_int small_int small_int small_int)
+      Gen.(tup5 nat_small nat_small nat_small nat_small nat_small)
       (fun (a, b, c, d, e) -> a < b && b < c && c < d && d < e)
 
   let test_tup6 =
     Test.make
       ~print:Print.(tup6 int int int int int int)
       ~name:"forall (a, b, c, d, e, f) in nat: a < b < c < d < e < f"
-      Gen.(tup6 small_int small_int small_int small_int small_int small_int)
+      Gen.(tup6 nat_small nat_small nat_small nat_small nat_small nat_small)
       (fun (a, b, c, d, e, f) -> a < b && b < c && c < d && d < e && e < f)
 
   let test_tup7 =
     Test.make
       ~print:Print.(tup7 int int int int int int int)
       ~name:"forall (a, b, c, d, e, f, g) in nat: a < b < c < d < e < f < g"
-      Gen.(tup7 small_int small_int small_int small_int small_int small_int small_int)
+      Gen.(tup7 nat_small nat_small nat_small nat_small nat_small nat_small nat_small)
       (fun (a, b, c, d, e, f, g) -> a < b && b < c && c < d && d < e && e < f && f < g)
 
   let test_tup8 =
     Test.make
       ~print:Print.(tup8 int int int int int int int int)
       ~name:"forall (a, b, c, d, e, f, g, h) in nat: a < b < c < d < e < f < g < h"
-      Gen.(tup8 small_int small_int small_int small_int small_int small_int small_int small_int)
+      Gen.(tup8 nat_small nat_small nat_small nat_small nat_small nat_small nat_small nat_small)
       (fun (a, b, c, d, e, f, g, h) -> a < b && b < c && c < d && d < e && e < f && f < g && g < h)
 
   let test_tup9 =
     Test.make
       ~print:Print.(tup9 int int int int int int int int int)
       ~name:"forall (a, b, c, d, e, f, g, h, i) in nat: a < b < c < d < e < f < g < h < i"
-      Gen.(tup9 small_int small_int small_int small_int small_int small_int small_int small_int small_int)
+      Gen.(tup9 nat_small nat_small nat_small nat_small nat_small nat_small nat_small nat_small nat_small)
       (fun (a, b, c, d, e, f, g, h, i) -> a < b && b < c && c < d && d < e && e < f && f < g && g < h && h < i)
 
   let bind_pair_ordered =
     Test.make ~name:"bind ordered pairs" ~print:Print.(pair int int)
-      Gen.(pint ~origin:0 >>= fun j -> int_bound j >>= fun i -> return (i,j))
+      Gen.(int_pos >>= fun j -> int_bound j >>= fun i -> return (i,j))
       (fun (_i,_j) -> false)
 
   let bind_pair_list_size =
@@ -664,36 +761,36 @@ module Shrink = struct
 
   let lists_are_empty_issue_64 =
     Test.make ~name:"lists are empty" ~print:Print.(list int)
-      Gen.(list small_int) (fun xs -> print_list xs; xs = [])
+      Gen.(list nat_small) (fun xs -> print_list xs; xs = [])
 
   let list_shorter_10 =
     Test.make ~name:"lists shorter than 10" ~print:Print.(list int)
-      Gen.(list small_int) (fun xs -> List.length xs < 10)
+      Gen.(list nat_small) (fun xs -> List.length xs < 10)
 
   let length_printer xs =
     Printf.sprintf "[...] list length: %i" (List.length xs)
 
-  let size_gen = Gen.(oneof [small_nat; int_bound 750_000])
+  let size_gen = Gen.(oneof [nat_small; int_bound 750_000])
 
   let list_shorter_432 =
     Test.make ~name:"lists shorter than 432" ~print:length_printer
-      Gen.(list_size size_gen small_int)
+      Gen.(list_size size_gen nat_small)
       (fun xs -> List.length xs < 432)
 
   let list_shorter_4332 =
     Test.make ~name:"lists shorter than 4332" ~print:length_printer
-      Gen.(list_size size_gen small_int)
+      Gen.(list_size size_gen nat_small)
       (fun xs -> List.length xs < 4332)
 
   let list_equal_dupl =
     Test.make ~name:"lists equal to duplication" ~print:Print.(list int)
-      Gen.(list_size size_gen small_int)
+      Gen.(list_size size_gen int_small)
       (fun xs -> try xs = xs @ xs
                  with Stack_overflow -> false)
 
   let list_unique_elems =
     Test.make ~name:"lists have unique elems" ~print:Print.(list int)
-      Gen.(list small_int)
+      Gen.(list nat_small)
       (fun xs -> let ys = List.sort_uniq Int.compare xs in
                  print_list xs; List.length xs = List.length ys)
 
@@ -719,8 +816,8 @@ module Shrink = struct
       (fun tree -> IntTree.contains_only_n tree 42)
 
   let test_gen_no_shrink =
-    Test.make ~name:"sum list = 0" ~print:Print.(list int)
-      Gen.(no_shrink @@ list small_int)
+    Test.make ~name:"sum list = 0 with no_shrink" ~print:Print.(list int)
+      Gen.(no_shrink @@ list nat_small)
       (fun xs -> List.fold_left (+) 0 xs = 0)
 
 
@@ -743,9 +840,35 @@ module Shrink = struct
     float_leq_1em10;
     float_geq_m1em10;
     float_geq_m1e10;
+    float_not_nan;
+    float_not_infinite;
+    float_bound_inclusive_1e6_leq_10;
+    float_bound_inclusive_1e6_leq_pi;
+    float_bound_inclusive_1_leq_5em1;
+    float_bound_inclusive_1_leq_min_float;
+    float_bound_inclusive_m1_geq_m5em1;
+    float_bound_inclusive_m1e6_geq_mpi;
+    float_bound_exclusive_1e6_leq_10;
+    float_bound_exclusive_1e6_leq_pi;
+    float_bound_exclusive_1_leq_5em1;
+    float_bound_exclusive_1_leq_min_float;
+    float_bound_exclusive_m1_geq_m5em1;
+    float_bound_exclusive_m1e6_geq_mpi;
+    float_range_1_10_leq_pi;
+    float_range_m10_10_square_leq_2;
+    float_range_m10_m1_geq_mpi;
+    float_pos_lt_pi;
+    float_pos_not_nan;
+    float_pos_not_infinite;
+    float_neg_gt_mpi;
+    float_neg_not_nan;
+    float_neg_not_infinite;
+    float_exp_10_lt_pi;
+    float_exp_m10_gt_mpi;
     char_is_never_abcdef;
-    printable_is_never_sign;
-    numeral_is_never_less_5;
+    char_range_is_never_abc;
+    char_printable_is_never_sign;
+    char_numeral_is_never_less_5;
     bytes_are_empty;
     bytes_never_has_000_char;
     bytes_never_has_255_char;
@@ -804,7 +927,7 @@ module Function = struct
     Test.make ~name:"fail_pred_map_commute_int" ~count:100 ~long_factor:100
       ~print:Print.(triple (list int) Fn.print Fn.print)
       Gen.(triple
-             (small_list small_int)
+             (list_small nat_small)
              (fun1 ~print:Print.int Observable.int int)
              (fun1 ~print:Print.bool Observable.int bool))
       (fun (l,Fun (_,f),Fun (_,p)) ->
@@ -814,7 +937,7 @@ module Function = struct
     Test.make ~name:"fail_pred_map_commute_int32" ~count:100 ~long_factor:100
       ~print:Print.(triple (list int32) Fn.print Fn.print)
       Gen.(triple
-             (small_list int32)
+             (list_small int32)
              (fun1 ~print:Print.int32 Observable.int32 int32)
              (fun1 ~print:Print.bool Observable.int32 bool))
       (fun (l,Fun (_,f),Fun (_,p)) ->
@@ -824,7 +947,7 @@ module Function = struct
     Test.make ~name:"fail_pred_map_commute_int64" ~count:100 ~long_factor:100
       ~print:Print.(triple (list int64) Fn.print Fn.print)
       Gen.(triple
-             (small_list int64)
+             (list_small int64)
              (fun1 ~print:Print.int64 Observable.int64 int64)
              (fun1 ~print:Print.bool Observable.int64 bool))
       (fun (l,Fun (_,f),Fun (_,p)) ->
@@ -835,7 +958,7 @@ module Function = struct
       (fun1 Observable.string ~print:Print.bool Gen.bool)
       (fun (Fun (_,p)) -> not (p "some random string") || p "some other string")
 
-  let int_gen = Gen.small_nat (* int *)
+  let int_gen = Gen.nat_small (* int *)
 
   (* Another example (false) property *)
   let prop_foldleft_foldright =
@@ -883,10 +1006,10 @@ module Function = struct
   let fold_left_test =
     Test.make ~name:"fold_left test, fun first" ~print:Print.(quad Fn.print string (list int) (list int))
       Gen.(quad  (* string -> int -> string *)
-             (fun2 ~print:Print.string Observable.string Observable.int (small_string ~gen:char))
-             (small_string ~gen:char)
-             (list small_int)
-             (list small_int))
+             (fun2 ~print:Print.string Observable.string Observable.int string_small)
+             string_small
+             (list nat_small)
+             (list nat_small))
       (fun (f,acc,is,js) ->
          let f = Fn.apply f in
          List.fold_left f acc (is @ js)
@@ -943,9 +1066,10 @@ module Stats = struct
 
   let char_dist_tests =
     [
-    Test.make ~name:"char code dist"           ~count:500_000 ~stats:[("char code", Char.code)] Gen.char      (fun _ -> true);
-    Test.make ~name:"printable char code dist" ~count:500_000 ~stats:[("char code", Char.code)] Gen.printable (fun _ -> true);
-    Test.make ~name:"numeral char code dist"   ~count:500_000 ~stats:[("char code", Char.code)] Gen.numeral   (fun _ -> true);
+    Test.make ~name:"char code dist"           ~count:500_000 ~stats:[("char code", Char.code)] Gen.char                 (fun _ -> true);
+    Test.make ~name:"char_range code dist"     ~count:500_000 ~stats:[("char code", Char.code)] (Gen.char_range 'A' 'Z') (fun _ -> true);
+    Test.make ~name:"char_printable code dist" ~count:500_000 ~stats:[("char code", Char.code)] Gen.char_printable       (fun _ -> true);
+    Test.make ~name:"char_numeral code dist"   ~count:500_000 ~stats:[("char code", Char.code)] Gen.char_numeral         (fun _ -> true);
   ]
 
   let bytes_len_tests =
@@ -955,7 +1079,7 @@ module Stats = struct
       Test.make ~name:"bytes len dist"           ~count:5_000 ~stats:[len] Gen.bytes                         (fun _ -> true);
       Test.make ~name:"bytes_of len dist"        ~count:5_000 ~stats:[len] Gen.(bytes_of (return 'a'))       (fun _ -> true);
       Test.make ~name:"bytes_printable len dist" ~count:5_000 ~stats:[len] Gen.bytes_printable               (fun _ -> true);
-      Test.make ~name:"bytes_small len dist"     ~count:5_000 ~stats:[len] Gen.(bytes_small_of char)         (fun _ -> true);
+      Test.make ~name:"bytes_small len dist"     ~count:5_000 ~stats:[len] Gen.bytes_small                   (fun _ -> true);
     ]
 
   let string_len_tests =
@@ -965,7 +1089,7 @@ module Stats = struct
       Test.make ~name:"string len dist"           ~count:5_000 ~stats:[len] Gen.string                         (fun _ -> true);
       Test.make ~name:"string_of len dist"        ~count:5_000 ~stats:[len] Gen.(string_of (return 'a'))       (fun _ -> true);
       Test.make ~name:"string_printable len dist" ~count:5_000 ~stats:[len] Gen.string_printable               (fun _ -> true);
-      Test.make ~name:"small_string len dist"     ~count:5_000 ~stats:[len] Gen.(small_string ~gen:char)(*ugh*)(fun _ -> true);
+      Test.make ~name:"string_small len dist"     ~count:5_000 ~stats:[len] Gen.string_small                   (fun _ -> true);
     ]
 
   let pair_dist =
@@ -997,35 +1121,37 @@ module Stats = struct
     let len = ("len",List.length) in
     [ (* test from issue #30 *)
       Test.make ~name:"list len dist"        ~count:5_000 ~stats:[len] Gen.(list int)                       (fun _ -> true);
-      Test.make ~name:"small_list len dist"  ~count:5_000 ~stats:[len] Gen.(small_list int)                 (fun _ -> true);
+      Test.make ~name:"list_small len dist"  ~count:5_000 ~stats:[len] Gen.(list_small int)                 (fun _ -> true);
       Test.make ~name:"list_size len dist"   ~count:5_000 ~stats:[len] Gen.(list_size (int_range 5 10) int) (fun _ -> true);
-      Test.make ~name:"list_repeat len dist" ~count:5_000 ~stats:[len] Gen.(list_repeat 42 int)             (fun _ -> true);
     ]
 
   let array_len_tests =
     let len = ("len",Array.length) in
     [
       Test.make ~name:"array len dist"        ~count:5_000 ~stats:[len] Gen.(array int)                       (fun _ -> true);
-      Test.make ~name:"small_array len dist"  ~count:5_000 ~stats:[len] Gen.(small_array int)                 (fun _ -> true);
+      Test.make ~name:"array_small len dist"  ~count:5_000 ~stats:[len] Gen.(array_small int)                 (fun _ -> true);
       Test.make ~name:"array_size len dist"   ~count:5_000 ~stats:[len] Gen.(array_size (int_range 5 10) int) (fun _ -> true);
-      Test.make ~name:"array_repeat len dist" ~count:5_000 ~stats:[len] Gen.(array_repeat 42 int)             (fun _ -> true);
     ]
 
   let int_dist_tests =
     let dist = ("dist",fun x -> x) in
     [
       (* test from issue #40 *)
-      Test.make ~name:"int_stats_neg"                  ~count:5000   ~stats:[dist] Gen.small_signed_int                 (fun _ -> true);
+      Test.make ~name:"int_stats_neg"                  ~count:5000   ~stats:[dist] Gen.int_small                        (fun _ -> true);
       (* distribution tests from PR #45 *)
-      Test.make ~name:"small_signed_int dist"          ~count:1000   ~stats:[dist] Gen.small_signed_int                 (fun _ -> true);
-      Test.make ~name:"small_nat dist"                 ~count:1000   ~stats:[dist] Gen.small_nat                        (fun _ -> true);
-      Test.make ~name:"nat dist"                       ~count:1000   ~stats:[dist] Gen.nat                              (fun _ -> true);
+      Test.make ~name:"int dist"                       ~count:100000 ~stats:[dist] Gen.int                              (fun _ -> true);
+      Test.make ~name:"int_bound 1000 dist"            ~count:10000  ~stats:[dist] (Gen.int_bound 1000)                 (fun _ -> true);
       Test.make ~name:"int_range (-43643) 435434 dist" ~count:1000   ~stats:[dist] (Gen.int_range (-43643) 435434)      (fun _ -> true);
       Test.make ~name:"int_range (-40000) 40000 dist"  ~count:1000   ~stats:[dist] (Gen.int_range (-40000) 40000)       (fun _ -> true);
       Test.make ~name:"int_range (-4) 4 dist"          ~count:1000   ~stats:[dist] (Gen.int_range (-4) 4)               (fun _ -> true);
       Test.make ~name:"int_range (-4) 17 dist"         ~count:1000   ~stats:[dist] (Gen.int_range (-4) 17)              (fun _ -> true);
-      Test.make ~name:"int dist"                       ~count:100000 ~stats:[dist] Gen.int                              (fun _ -> true);
-      Test.make ~name:"oneof int dist"                 ~count:1000   ~stats:[dist] (Gen.oneofl[min_int;-1;0;1;max_int]) (fun _ -> true);
+      Test.make ~name:"int_small dist"                 ~count:1000   ~stats:[dist] Gen.int_small                        (fun _ -> true);
+      Test.make ~name:"int_small_corners dist"         ~count:1000   ~stats:[dist] (Gen.int_small_corners ())           (fun _ -> true);
+      Test.make ~name:"int_neg dist"                   ~count:10000  ~stats:[dist] Gen.int_neg                          (fun _ -> true);
+      Test.make ~name:"int_pos dist"                   ~count:10000  ~stats:[dist] Gen.int_pos                          (fun _ -> true);
+      Test.make ~name:"oneof_list int dist"            ~count:1000   ~stats:[dist] (Gen.oneof_list[min_int;-1;0;1;max_int]) (fun _ -> true);
+      Test.make ~name:"nat dist"                       ~count:1000   ~stats:[dist] Gen.nat                              (fun _ -> true);
+      Test.make ~name:"nat_small dist"                 ~count:1000   ~stats:[dist] Gen.nat_small                        (fun _ -> true);
     ]
 
   let int_32_64_dist_tests =
@@ -1040,7 +1166,7 @@ module Stats = struct
       Test.make ~name:"int64 upper dist"     ~count:10000 ~stats:(stat64 (fun i -> Int64.shift_right_logical i 48)) Gen.int64 (fun _ -> true);
     ]
 
-  let exponential_tests =
+  let float_exp_tests =
     let float_dist = ("dist",int_of_float) in
     [ Test.make ~name:"exponential 10. dist" ~count:5_000 ~stats:[float_dist] (Gen.exponential 10.) (fun _ -> true);
       Test.make ~name:"exponential -10. dist" ~count:5_000 ~stats:[float_dist] (Gen.exponential (-10.)) (fun _ -> true);
@@ -1067,7 +1193,7 @@ module Stats = struct
 
   let int_dist_empty_bucket =
     Test.make ~name:"int_dist_empty_bucket" ~count:1_000 ~stats:[("dist",fun x -> x)]
-      Gen.(oneof [small_int_corners ();int]) (fun _ -> true)
+      Gen.(oneof [int_small_corners ();int]) (fun _ -> true)
 
   let tests =
     [ bool_dist; ]
@@ -1085,6 +1211,6 @@ module Stats = struct
     @ array_len_tests
     @ int_dist_tests
     @ int_32_64_dist_tests
-    @ exponential_tests
+    @ float_exp_tests
     @ float_tests
 end
