@@ -26,7 +26,7 @@ module IntTree = struct
                         (fun self n -> match n with
                            | 0 -> map leaf nat
                            | n ->
-                             frequency
+                             oneof_weighted
                                [1, map leaf nat;
                                 2, map2 node (self (n/2)) (self (n/2))]
                         ))
@@ -54,15 +54,15 @@ module Overall = struct
 
   let passing =
     Test.make ~name:"list_rev_is_involutive" ~count:100 ~long_factor:100
-      (list small_int) (fun l -> List.rev (List.rev l) = l)
+      (list int_small) (fun l -> List.rev (List.rev l) = l)
 
   let failing =
     Test.make ~name:"should_fail_sort_id" ~count:10
-      (small_list small_int) (fun l -> l = List.sort compare l)
+      (list_small nat_small) (fun l -> l = List.sort compare l)
 
   let max_fail =
     Test.make ~name:"max_fail" ~count:1000 ~max_fail:3
-      (list small_nat)
+      (list nat_small)
       (fun l -> l = List.rev l)
 
   exception Error
@@ -87,7 +87,7 @@ module Overall = struct
 
   let retries =
     Test.make ~name:"with shrinking retries" ~retries:10
-      small_nat (fun i -> Printf.printf "%i %!" i; i mod 3 <> 1)
+      nat_small (fun i -> Printf.printf "%i %!" i; i mod 3 <> 1)
 
   let bad_assume_warn =
     Test.make ~name:"WARN_unlikely_precond" ~count:2_000
@@ -117,20 +117,20 @@ module Overall = struct
       (fun _i -> false)
 
   let neg_test_fail_as_expected =
-    Test.make_neg ~name:"all ints are even" small_int (fun i -> i mod 2 = 0)
+    Test.make_neg ~name:"all ints are even" int_small (fun i -> i mod 2 = 0)
 
   let neg_test_unexpected_success =
-    Test.make_neg ~name:"int double" small_int (fun i -> i + i = i * 2)
+    Test.make_neg ~name:"int double" int_small (fun i -> i + i = i * 2)
 
   let neg_test_fail_with_shrinking =
     Test.make_neg ~name:"list rev concat"
-      (pair (list small_int) (list small_int)) (fun (is,js) -> (List.rev is)@(List.rev js) = List.rev (is@js))
+      (pair (list int_small) (list int_small)) (fun (is,js) -> (List.rev is)@(List.rev js) = List.rev (is@js))
 
   let pos_test_fails_with_error =
-    Test.make ~name:"pos fail with error" small_int (fun _i -> raise Error)
+    Test.make ~name:"pos fail with error" nat_small (fun _i -> raise Error)
 
   let neg_test_fail_with_error =
-    Test.make_neg ~name:"neg fail with error" small_int (fun _i -> raise Error)
+    Test.make_neg ~name:"neg fail with error" nat_small (fun _i -> raise Error)
 
   (* [apply_n f x n] computes f(f(...f(x))) with n applications of f *)
   let rec apply_n f x n =
@@ -143,7 +143,7 @@ module Overall = struct
     let sleep_time = 0.175 in
     let count = ref 0 in
     Test.make ~count:10 ~name:"bad function reproducability"
-      (set_shrink Shrink.nil (triple small_int (fun1 Observable.int small_int) small_int))
+      (set_shrink Shrink.nil (triple nat_small (fun1 Observable.int nat_small) nat_small))
       (fun (i,f,j) ->
          incr count;
          Printf.printf "(%i,fun,%i)%s%!" i j (if !count mod 10 = 0 then "\n" else " ");
@@ -195,13 +195,17 @@ module Generator = struct
     Test.make ~name:"char has right range" ~count:1000
       char (fun c -> '\000' <= c && c <= '\255')
 
-  let printable_test =
-    Test.make ~name:"printable has right range" ~count:1000
-      printable_char (fun c -> c = '\n' || 32 <= Char.code c && Char.code c <= 126)
+  let char_range_test =
+    Test.make ~name:"char_range 'a' 'z' has right range" ~count:1000
+      (char_range 'a' 'z') (fun c -> 'a' <= c && c <= 'z')
 
-  let numeral_test =
-    Test.make ~name:"numeral has right range" ~count:1000
-      numeral_char (fun c -> '0' <= c && c <= '9')
+  let char_printable_test =
+    Test.make ~name:"char_printable has right range" ~count:1000
+      char_printable (fun c -> c = '\n' || 32 <= Char.code c && Char.code c <= 126)
+
+  let char_numeral_test =
+    Test.make ~name:"char_numeral has right range" ~count:1000
+      char_numeral (fun c -> '0' <= c && c <= '9')
 
   let nat_test =
     Test.make ~name:"nat has right range" ~count:1000
@@ -239,15 +243,15 @@ module Generator = struct
 
   let pair_test =
     Test.make ~name:"int pairs - commute over +" ~count:1000
-      (pair small_nat small_nat) (fun (i,j) -> i+j = j+i)
+      (pair nat_small nat_small) (fun (i,j) -> i+j = j+i)
 
   let triple_test =
     Test.make ~name:"int triples - associative over +" ~count:1000
-      (triple small_nat small_nat small_nat) (fun (i,j,k) -> i+(j+k) = (i+j)+k)
+      (triple nat_small nat_small nat_small) (fun (i,j,k) -> i+(j+k) = (i+j)+k)
 
   let quad_test =
     Test.make ~name:"int quadruples - product of sums" ~count:1000
-      (quad small_nat small_nat small_nat small_nat)
+      (quad nat_small nat_small nat_small nat_small)
       (fun (h,i,j,k) -> (h+i)*(j+k) = h*j + h*k + i*j + i*k)
 
   let test_tup2 =
@@ -306,7 +310,7 @@ module Generator = struct
 
   let bind_test =
     Test.make ~name:"bind test for ordered pairs" ~count:1000
-      (make Gen.(small_nat >>= fun j -> int_bound j >>= fun i -> return (i,j)))
+      (make Gen.(nat_small >>= fun j -> int_bound j >>= fun i -> return (i,j)))
       (fun (i,j) -> i<=j)
 
   let bind_pair_list_length =
@@ -319,16 +323,6 @@ module Generator = struct
     Test.make ~name:"list has right length" ~count:1000
       (list unit) (fun l -> let len = List.length l in 0 <= len && len < 10_000)
 
-  let list_repeat_test =
-    let gen = Gen.(small_nat >>= fun i -> list_repeat i unit >>= fun l -> return (i,l)) in
-    Test.make ~name:"list_repeat has constant length" ~count:1000
-      (make ~print:Print.(pair int (list unit)) gen) (fun (i,l) -> List.length l = i)
-
-  let array_repeat_test =
-    let gen = Gen.(small_nat >>= fun i -> array_repeat i unit >>= fun l -> return (i,l)) in
-    Test.make ~name:"array_repeat has constant length" ~count:1000
-      (make ~print:Print.(pair int (array unit)) gen) (fun (i,l) -> Array.length l = i)
-
   let int_option_test =
     Test.make ~name:"int option right range" ~count:1000
       (option (int_bound 1000)) (function None -> true | Some i -> 0 <= i && i <= 1000)
@@ -346,7 +340,7 @@ module Generator = struct
     Test.make ~name:"nat_split2 spec"
       (make
         ~print:Print.(pair int (pair int int))
-         Gen.(small_nat >>= fun n ->
+         Gen.(nat_small >>= fun n ->
               pair (return n) (nat_split2 n)))
       (fun (n, (a, b)) ->
          0 <= a && 0 <= b && a + b = n)
@@ -355,7 +349,7 @@ module Generator = struct
     Test.make ~name:"pos_split2 spec"
       (make
         ~print:Print.(pair int (pair int int))
-         Gen.(small_nat >>= fun n ->
+         Gen.(nat_small >>= fun n ->
               (* we need n > 2 *)
               let n = n + 2 in
               pair (return n) (pos_split2 n)))
@@ -366,7 +360,7 @@ module Generator = struct
     Test.make ~name:"range_subset_spec"
       (make
          ~print:Print.(quad int int int (array int))
-         Gen.(pair small_nat small_nat >>= fun (m, n) ->
+         Gen.(pair nat_small nat_small >>= fun (m, n) ->
               (* we must guarantee [low <= high]
                  and [size <= high - low + 1] *)
               let low = m and high = m + n in
@@ -386,7 +380,7 @@ module Generator = struct
     Test.make ~name:"nat_split n-way"
       (make
          ~print:Print.(pair int (array int))
-         Gen.(small_nat >>= fun n ->
+         Gen.(nat_small >>= fun n ->
               pair (return n) (nat_split ~size:n n)))
       (fun (n, arr) ->
          Array.length arr = n
@@ -397,7 +391,7 @@ module Generator = struct
     Test.make ~name:"nat_split smaller"
       (make
          ~print:Print.(triple int int (array int))
-         Gen.(small_nat >>= fun size ->
+         Gen.(nat_small >>= fun size ->
               int_bound size >>= fun n ->
               triple (return size) (return n) (nat_split ~size n)))
       (fun (m, n, arr) ->
@@ -409,7 +403,7 @@ module Generator = struct
     Test.make ~name:"pos_split"
       (make
          ~print:Print.(triple int int (array int))
-         Gen.(pair small_nat small_nat >>= fun (m, n) ->
+         Gen.(pair nat_small nat_small >>= fun (m, n) ->
               (* we need both size>0 and n>0 and size <= n *)
               let size = 1 + min m n and n = 1 + max m n in
               triple (return size) (return n) (pos_split ~size n)))
@@ -424,8 +418,9 @@ module Generator = struct
   let tests = [
     char_dist_issue_23;
     char_test;
-    printable_test;
-    numeral_test;
+    char_range_test;
+    char_printable_test;
+    char_numeral_test;
     nat_test;
     int_test;
     int32_test;
@@ -446,17 +441,15 @@ module Generator = struct
     bind_test;
     bind_pair_list_length;
     list_test;
-    list_repeat_test;
-    array_repeat_test;
     int_option_test;
     int_string_result_test;
     passing_tree_rev;
-    nat_split2_spec;
+    nat_split2_spec; (* Features (and tests) only available in QCheck for now, not QCheck2 *)
     pos_split2_spec;
     range_subset_spec;
     nat_split_n_way;
     nat_split_smaller;
-    pos_split;
+    pos_split;       (* ... up until this one *)
     float_test;
   ]
 end
@@ -472,7 +465,7 @@ module Shrink = struct
   (* example from issue #59 *)
   let test_fac_issue59 =
     Test.make ~name:"test fac issue59"
-      (set_shrink Shrink.nil (small_int_corners ()))
+      (set_shrink Shrink.nil (int_small_corners ()))
       (fun n -> try (fac n) mod n = 0
                 with
                 (*| Stack_overflow   -> false*)
@@ -480,10 +473,10 @@ module Shrink = struct
 
   let big_bound_issue59 =
     Test.make ~name:"big bound issue59"
-      (small_int_corners()) (fun i -> i < 209609)
+      (int_small_corners()) (fun i -> i < 209609)
 
   let long_shrink =
-    let listgen = list_of_size (Gen.int_range 1000 10000) int in
+    let listgen = list_size (Gen.int_range 1000 10000) int in
     Test.make ~name:"long_shrink" (pair listgen listgen)
       (fun (xs,ys) -> List.rev (xs@ys) = (List.rev xs)@(List.rev ys))
 
@@ -515,7 +508,7 @@ module Shrink = struct
   (* test from issue #59 *)
   let ints_smaller_209609 =
     Test.make ~name:"ints < 209609"
-      (small_int_corners()) (fun i -> i < 209609)
+      (int_small_corners()) (fun i -> i < 209609)
 
   let nats_smaller_5001 =
     Test.make ~name:"nat < 5001" ~count:1000
@@ -617,45 +610,54 @@ module Shrink = struct
     Test.make ~name:"float_range -10. -1. >= -.pi" ~count:1000
       (float_range (-10.) (-1.)) (fun f -> f >= -.Float.pi)
 
-  let pos_float_lt_pi =
-    Test.make ~name:"pos_float < Float.pi" ~count:1000
-      pos_float (fun f -> f < Float.pi)
+  let float_pos_lt_pi =
+    Test.make ~name:"float_pos < Float.pi" ~count:1000
+      float_pos (fun f -> f < Float.pi)
 
-  let pos_float_not_nan =
-    Test.make ~name:"pos_float is not nan" ~count:10_000
-      pos_float (fun f -> not (Float.is_nan f))
+  let float_pos_not_nan =
+    Test.make ~name:"float_pos is not nan" ~count:10_000
+      float_pos (fun f -> not (Float.is_nan f))
 
-  let pos_float_not_infinite =
-    Test.make ~name:"pos_float is not infinity" ~count:10_000
-      pos_float (fun f -> not (Float.is_infinite f))
+  let float_pos_not_infinite =
+    Test.make ~name:"float_pos is not infinity" ~count:10_000
+      float_pos (fun f -> not (Float.is_infinite f))
 
-  let neg_float_gt_mpi =
-    Test.make ~name:"neg_float > Float.pi" ~count:1000
-      neg_float (fun f -> f > -.Float.pi)
+  let float_neg_gt_mpi =
+    Test.make ~name:"float_neg > Float.pi" ~count:1000
+      float_neg (fun f -> f > -.Float.pi)
 
-  let neg_float_not_nan =
-    Test.make ~name:"neg_float is not nan" ~count:10_000
-      neg_float (fun f -> not (Float.is_nan f))
+  let float_neg_not_nan =
+    Test.make ~name:"float_neg is not nan" ~count:10_000
+      float_neg (fun f -> not (Float.is_nan f))
 
-  let neg_float_not_infinite =
-    Test.make ~name:"neg_float is not infinity" ~count:10_000
-      neg_float (fun f -> not (Float.is_infinite f))
+  let float_neg_not_infinite =
+    Test.make ~name:"float_neg is not infinity" ~count:10_000
+      float_neg (fun f -> not (Float.is_infinite f))
 
-  let exponential_10_lt_pi =
-    Test.make ~name:"exponential 10. < Float.pi" ~count:1000
-      (exponential 10.) (fun f -> f < Float.pi)
+  let float_exp_10_lt_pi =
+    Test.make ~name:"float_exp 10. < Float.pi" ~count:1000
+      (float_exp 10.) (fun f -> f < Float.pi)
+
+  let float_exp_m10_gt_mpi =
+    Test.make ~name:"float_exp -10. > -. Float.pi" ~count:1000
+      (float_exp (-10.)) (fun f -> f > -. Float.pi)
 
   let char_is_never_abcdef =
     Test.make ~name:"char never produces 'abcdef'" ~count:1000
       char (fun c -> not (List.mem c ['a';'b';'c';'d';'e';'f']))
 
-  let printable_is_never_sign = (* should shrink towards 'a', hence produce '&' with highest ascii code 38 *)
-    Test.make ~name:"printable never produces '!\"#$%&'" ~count:1000
-      printable_char (fun c -> not (List.mem c ['!';'"';'#';'$';'%';'&']))
+  let char_range_is_never_abc =
+    Test.make ~name:"char never 'abc'" ~count:1000
+      (char_range 'a' 'z') (fun c -> not (c < 'c'))
+
+  let char_printable_is_never_sign = (* should shrink towards 'a', hence produce '&' with highest ascii code 38 *)
+    Test.make ~name:"char_printable never produces '!\"#$%&'" ~count:1000
+      char_printable (fun c -> not (List.mem c ['!';'"';'#';'$';'%';'&']))
+
+  let char_numeral_is_never_less_5 =
+    Test.make ~name:"char_numeral never produces less than '5'" ~count:1000
+      char_numeral (fun c -> c >= '5')
 
-  let numeral_is_never_less_5 =
-    Test.make ~name:"printable never produces less than '5" ~count:1000
-      numeral_char (fun c -> c >= '5')
   let bytes_are_empty =
     Test.make ~name:"bytes are empty" ~count:1000
       bytes (fun b -> b = Bytes.empty)
@@ -701,7 +703,7 @@ module Shrink = struct
   (* test from issue #167 *)
   let pair_diff_issue_64 =
     Test.make ~name:"pairs have different components"
-      (pair small_int small_int) (fun (i,j) -> i<>j)
+      (pair nat_small nat_small) (fun (i,j) -> i<>j)
 
   let pair_same =
     Test.make ~name:"pairs have same components" (pair int int) (fun (i,j) -> i=j)
@@ -713,27 +715,27 @@ module Shrink = struct
     Test.make ~name:"pairs are (0,0)" (pair int int) (fun (i,j) -> i=0 && j=0)
 
   let pair_ordered =
-    Test.make ~name:"pairs are ordered" (pair pos_int pos_int) (fun (i,j) -> i<=j)
+    Test.make ~name:"pairs are ordered" (pair int_pos int_pos) (fun (i,j) -> i<=j)
 
   let pair_ordered_rev =
-    Test.make ~name:"pairs are ordered reversely" (pair pos_int pos_int) (fun (i,j) -> i>=j)
+    Test.make ~name:"pairs are ordered reversely" (pair int_pos int_pos) (fun (i,j) -> i>=j)
 
   let pair_sum_lt_128 =
-    Test.make ~name:"pairs sum to less than 128" (pair pos_int pos_int) (fun (i,j) -> i+j<128)
+    Test.make ~name:"pairs sum to less than 128" (pair int_pos int_pos) (fun (i,j) -> i+j<128)
 
   let pair_lists_rev_concat =
     Test.make ~name:"pairs lists rev concat"
-      (pair (list pos_int) (list pos_int))
+      (pair (list int_pos) (list int_pos))
       (fun (xs,ys) -> List.rev (xs@ys) = (List.rev xs)@(List.rev ys))
 
   let pair_lists_no_overlap =
     Test.make ~name:"pairs lists no overlap"
-      (pair (list small_nat) (list small_nat))
+      (pair (list nat_small) (list nat_small))
       (fun (xs,ys) -> List.for_all (fun x -> not (List.mem x ys)) xs)
 
   let triple_diff =
     Test.make ~name:"triples have pair-wise different components"
-      (triple small_int small_int small_int) (fun (i,j,k) -> i<>j && j<>k)
+      (triple nat_small nat_small nat_small) (fun (i,j,k) -> i<>j && j<>k)
 
   let triple_same =
     Test.make ~name:"triples have same components"
@@ -749,7 +751,7 @@ module Shrink = struct
 
   let quad_diff =
     Test.make ~name:"quadruples have pair-wise different components"
-      (quad small_int small_int small_int small_int) (fun (h,i,j,k) -> h<>i && i<>j && j<>k)
+      (quad nat_small nat_small nat_small nat_small) (fun (h,i,j,k) -> h<>i && i<>j && j<>k)
 
   let quad_same =
     Test.make ~name:"quadruples have same components"
@@ -766,56 +768,56 @@ module Shrink = struct
   let test_tup2 =
     Test.make
       ~name:"forall (a, b) in nat: a < b"
-      (tup2 small_int small_int)
+      (tup2 nat_small nat_small)
       (fun (a, b) -> a < b)
 
   let test_tup3 =
     Test.make
       ~name:"forall (a, b, c) in nat: a < b < c"
-      (tup3 small_int small_int small_int)
+      (tup3 nat_small nat_small nat_small)
       (fun (a, b, c) -> a < b && b < c)
 
   let test_tup4 =
     Test.make
       ~name:"forall (a, b, c, d) in nat: a < b < c < d"
-      (tup4 small_int small_int small_int small_int)
+      (tup4 nat_small nat_small nat_small nat_small)
       (fun (a, b, c, d) -> a < b && b < c && c < d)
 
   let test_tup5 =
     Test.make
       ~name:"forall (a, b, c, d, e) in nat: a < b < c < d < e"
-      (tup5 small_int small_int small_int small_int small_int)
+      (tup5 nat_small nat_small nat_small nat_small nat_small)
       (fun (a, b, c, d, e) -> a < b && b < c && c < d && d < e)
 
   let test_tup6 =
     Test.make
       ~name:"forall (a, b, c, d, e, f) in nat: a < b < c < d < e < f"
-      (tup6 small_int small_int small_int small_int small_int small_int)
+      (tup6 nat_small nat_small nat_small nat_small nat_small nat_small)
       (fun (a, b, c, d, e, f) -> a < b && b < c && c < d && d < e && e < f)
 
   let test_tup7 =
     Test.make
       ~name:"forall (a, b, c, d, e, f, g) in nat: a < b < c < d < e < f < g"
-      (tup7 small_int small_int small_int small_int small_int small_int small_int)
+      (tup7 nat_small nat_small nat_small nat_small nat_small nat_small nat_small)
       (fun (a, b, c, d, e, f, g) -> a < b && b < c && c < d && d < e && e < f && f < g)
 
   let test_tup8 =
     Test.make
       ~name:"forall (a, b, c, d, e, f, g, h) in nat: a < b < c < d < e < f < g < h"
-      (tup8 small_int small_int small_int small_int small_int small_int small_int small_int)
+      (tup8 nat_small nat_small nat_small nat_small nat_small nat_small nat_small nat_small)
       (fun (a, b, c, d, e, f, g, h) -> a < b && b < c && c < d && d < e && e < f && f < g && g < h)
 
   let test_tup9 =
     Test.make
       ~name:"forall (a, b, c, d, e, f, g, h, i) in nat: a < b < c < d < e < f < g < h < i"
-      (tup9 small_int small_int small_int small_int small_int small_int small_int small_int small_int)
+      (tup9 nat_small nat_small nat_small nat_small nat_small nat_small nat_small nat_small nat_small)
       (fun (a, b, c, d, e, f, g, h, i) -> a < b && b < c && c < d && d < e && e < f && f < g && g < h && h < i)
 
   let bind_pair_ordered =
     Test.make ~name:"bind ordered pairs"
       (make ~print:Print.(pair int int)
          ~shrink:Shrink.(filter (fun (i,j) -> i<=j) (pair int int))
-         Gen.(pint >>= fun j -> int_bound j >>= fun i -> return (i,j)))
+         Gen.(int_pos >>= fun j -> int_bound j >>= fun i -> return (i,j)))
       (fun (_i,_j) -> false)
 
   let bind_pair_list_size =
@@ -832,36 +834,36 @@ module Shrink = struct
   (* test from issue #64 *)
   let lists_are_empty_issue_64 =
     Test.make ~name:"lists are empty"
-      (list small_int) (fun xs -> print_list xs; xs = [])
+      (list nat_small) (fun xs -> print_list xs; xs = [])
 
   let list_shorter_10 =
     Test.make ~name:"lists shorter than 10"
-      (list small_int) (fun xs -> List.length xs < 10)
+      (list nat_small) (fun xs -> List.length xs < 10)
 
   let length_printer xs =
     Printf.sprintf "[...] list length: %i" (List.length xs)
 
-  let size_gen = Gen.(oneof [small_nat; int_bound 750_000])
+  let size_gen = Gen.(oneof [nat_small; int_bound 750_000])
 
   let list_shorter_432 =
     Test.make ~name:"lists shorter than 432"
-      (set_print length_printer (list_of_size size_gen small_int))
+      (set_print length_printer (list_size size_gen nat_small))
       (fun xs -> List.length xs < 432)
 
   let list_shorter_4332 =
     Test.make ~name:"lists shorter than 4332"
-      (set_shrink Shrink.list_spine (set_print length_printer (list_of_size size_gen small_int)))
+      (set_shrink Shrink.list_spine (set_print length_printer (list_size size_gen nat_small)))
       (fun xs -> List.length xs < 4332)
 
   let list_equal_dupl =
     Test.make ~name:"lists equal to duplication"
-      (list_of_size size_gen small_int)
+      (list_size size_gen int_small)
       (fun xs -> try xs = xs @ xs
                  with Stack_overflow -> false)
 
   let list_unique_elems =
     Test.make ~name:"lists have unique elems"
-      (list small_int)
+      (list nat_small)
       (fun xs -> let ys = List.sort_uniq Int.compare xs in
                  print_list xs; List.length xs = List.length ys)
 
@@ -887,8 +889,8 @@ module Shrink = struct
       (fun tree -> IntTree.contains_only_n tree 42)
 
   let test_gen_no_shrink =
-    Test.make ~name:"sum list = 0"
-      (set_shrink Shrink.nil (list small_int))
+    Test.make ~name:"sum list = 0 with no_shrink"
+      (no_shrink @@ list nat_small)
       (fun xs -> List.fold_left (+) 0 xs = 0)
 
   let tests = [
@@ -927,16 +929,18 @@ module Shrink = struct
     float_range_1_10_leq_pi;
     float_range_m10_10_square_leq_2;
     float_range_m10_m1_geq_mpi;
-    pos_float_lt_pi;
-    pos_float_not_nan;
-    pos_float_not_infinite;
-    neg_float_gt_mpi;
-    neg_float_not_nan;
-    neg_float_not_infinite;
-    exponential_10_lt_pi;
+    float_pos_lt_pi;
+    float_pos_not_nan;
+    float_pos_not_infinite;
+    float_neg_gt_mpi;
+    float_neg_not_nan;
+    float_neg_not_infinite;
+    float_exp_10_lt_pi;
+    float_exp_m10_gt_mpi;
     char_is_never_abcdef;
-    printable_is_never_sign;
-    numeral_is_never_less_5;
+    char_range_is_never_abc;
+    char_printable_is_never_sign;
+    char_numeral_is_never_less_5;
     bytes_are_empty;
     bytes_never_has_000_char;
     bytes_never_has_255_char;
@@ -994,7 +998,7 @@ module Function = struct
   let fail_pred_map_commute_int =
     Test.make ~name:"fail_pred_map_commute_int" ~count:100 ~long_factor:100
       (triple
-         (small_list small_int)
+         (list_small nat_small)
          (fun1 Observable.int int)
          (fun1 Observable.int bool))
       (fun (l,Fun (_,f),Fun (_,p)) ->
@@ -1003,7 +1007,7 @@ module Function = struct
   let fail_pred_map_commute_int32 =
     Test.make ~name:"fail_pred_map_commute_int32" ~count:100 ~long_factor:100
       (triple
-         (small_list int32)
+         (list_small int32)
          (fun1 Observable.int32 int32)
          (fun1 Observable.int32 bool))
       (fun (l,Fun (_,f),Fun (_,p)) ->
@@ -1012,7 +1016,7 @@ module Function = struct
   let fail_pred_map_commute_int64 =
     Test.make ~name:"fail_pred_map_commute_int64" ~count:100 ~long_factor:100
       (triple
-         (small_list int64)
+         (list_small int64)
          (fun1 Observable.int64 int64)
          (fun1 Observable.int64 bool))
       (fun (l,Fun (_,f),Fun (_,p)) ->
@@ -1023,7 +1027,7 @@ module Function = struct
       (fun1 Observable.string bool)
       (fun (Fun (_,p)) -> not (p "some random string") || p "some other string")
 
-  let int_gen = small_nat (* int *)
+  let int_gen = nat_small (* int *)
 
   (* Another example (false) property *)
   let prop_foldleft_foldright =
@@ -1068,10 +1072,10 @@ module Function = struct
   let fold_left_test =
     Test.make ~name:"fold_left test, fun first"
       (quad  (* string -> int -> string *)
-         (fun2 Observable.string Observable.int small_string)
-         small_string
-         (list small_int)
-         (list small_int))
+         (fun2 Observable.string Observable.int string_small)
+         string_small
+         (list nat_small)
+         (list nat_small))
       (fun (f,acc,is,js) ->
          let f = Fn.apply f in
          List.fold_left f acc (is @ js)
@@ -1127,28 +1131,29 @@ module Stats = struct
 
   let char_dist_tests =
     [
-      Test.make ~name:"char code dist"           ~count:500_000 (add_stat ("char code", Char.code) char)           (fun _ -> true);
-      Test.make ~name:"printable char code dist" ~count:500_000 (add_stat ("char code", Char.code) printable_char) (fun _ -> true);
-      Test.make ~name:"numeral char code dist"   ~count:500_000 (add_stat ("char code", Char.code) numeral_char)   (fun _ -> true);
+      Test.make ~name:"char code dist"           ~count:500_000 (add_stat ("char code", Char.code) char)                 (fun _ -> true);
+      Test.make ~name:"char_range code dist"     ~count:500_000 (add_stat ("char code", Char.code) (char_range 'A' 'Z')) (fun _ -> true);
+      Test.make ~name:"char_printable code dist" ~count:500_000 (add_stat ("char code", Char.code) char_printable)       (fun _ -> true);
+      Test.make ~name:"char_numeral code dist"   ~count:500_000 (add_stat ("char code", Char.code) char_numeral)         (fun _ -> true);
     ]
 
   let bytes_len_tests =
     let len = ("len",Bytes.length) in
     [
-      Test.make ~name:"bytes_size len dist"      ~count:5_000 (add_stat len (bytes_of_size (Gen.int_range 5 10))) (fun _ -> true);
-      Test.make ~name:"bytes len dist"           ~count:5_000 (add_stat len bytes)                                (fun _ -> true);
-      Test.make ~name:"bytes_of len dist"        ~count:5_000 (add_stat len (bytes_of (Gen.return 'a')))          (fun _ -> true);
-      Test.make ~name:"bytes_small len dist"     ~count:5_000 (add_stat len bytes_small)                          (fun _ -> true);
+      Test.make ~name:"bytes_size len dist"      ~count:5_000 (add_stat len (bytes_size (Gen.int_range 5 10))) (fun _ -> true);
+      Test.make ~name:"bytes len dist"           ~count:5_000 (add_stat len bytes)                             (fun _ -> true);
+      Test.make ~name:"bytes_of len dist"        ~count:5_000 (add_stat len (bytes_of (Gen.return 'a')))       (fun _ -> true);
+      Test.make ~name:"bytes_small len dist"     ~count:5_000 (add_stat len bytes_small)                       (fun _ -> true);
     ]
 
   let string_len_tests =
     let len = ("len",String.length) in
     [
-      Test.make ~name:"string_size len dist"      ~count:5_000 (add_stat len (string_of_size (Gen.int_range 5 10))) (fun _ -> true);
-      Test.make ~name:"string len dist"           ~count:5_000 (add_stat len string)                                (fun _ -> true);
-      Test.make ~name:"string_of len dist"        ~count:5_000 (add_stat len (string_of (Gen.return 'a')))          (fun _ -> true);
-      Test.make ~name:"printable_string len dist" ~count:5_000 (add_stat len printable_string)                      (fun _ -> true);
-      Test.make ~name:"small_string len dist"     ~count:5_000 (add_stat len small_string)                          (fun _ -> true);
+      Test.make ~name:"string_size len dist"      ~count:5_000 (add_stat len (string_size (Gen.int_range 5 10))) (fun _ -> true);
+      Test.make ~name:"string len dist"           ~count:5_000 (add_stat len string)                             (fun _ -> true);
+      Test.make ~name:"string_of len dist"        ~count:5_000 (add_stat len (string_of (Gen.return 'a')))       (fun _ -> true);
+      Test.make ~name:"string_printable len dist" ~count:5_000 (add_stat len string_printable)                   (fun _ -> true);
+      Test.make ~name:"string_small len dist"     ~count:5_000 (add_stat len string_small)                       (fun _ -> true);
     ]
 
   let pair_dist =
@@ -1182,35 +1187,37 @@ module Stats = struct
   let list_len_tests =
     let len = ("len",List.length) in
     [ (* test from issue #30 *)
-      Test.make ~name:"list len dist"         ~count:5_000 (add_stat len (list int))                              (fun _ -> true);
-      Test.make ~name:"small_list len dist"   ~count:5_000 (add_stat len (small_list int))                        (fun _ -> true);
-      Test.make ~name:"list_of_size len dist" ~count:5_000 (add_stat len (list_of_size (Gen.int_range 5 10) int)) (fun _ -> true);
-      Test.make ~name:"list_repeat len dist"  ~count:5_000 (add_stat len (make Gen.(list_repeat 42 int)))         (fun _ -> true);
+      Test.make ~name:"list len dist"        ~count:5_000 (add_stat len (list int))                           (fun _ -> true);
+      Test.make ~name:"list_small len dist"  ~count:5_000 (add_stat len (list_small int))                     (fun _ -> true);
+      Test.make ~name:"list_size len dist"   ~count:5_000 (add_stat len (list_size (Gen.int_range 5 10) int)) (fun _ -> true);
     ]
 
   let array_len_tests =
     let len = ("len",Array.length) in
     [
-      Test.make ~name:"array len dist"         ~count:5_000 (add_stat len (array int))                              (fun _ -> true);
-      Test.make ~name:"small_array len dist"   ~count:5_000 (add_stat len (make Gen.(small_array int)))             (fun _ -> true);
-      Test.make ~name:"array_of_size len dist" ~count:5_000 (add_stat len (array_of_size (Gen.int_range 5 10) int)) (fun _ -> true);
-      Test.make ~name:"array_repeat len dist"  ~count:5_000 (add_stat len (make Gen.(array_repeat 42 int)))         (fun _ -> true);
+      Test.make ~name:"array len dist"        ~count:5_000 (add_stat len (array int))                           (fun _ -> true);
+      Test.make ~name:"array_small len dist"  ~count:5_000 (add_stat len (array_small int))                     (fun _ -> true);
+      Test.make ~name:"array_size len dist"   ~count:5_000 (add_stat len (array_size (Gen.int_range 5 10) int)) (fun _ -> true);
     ]
 
   let int_dist_tests =
     let dist = ("dist",fun x -> x) in
     [ (* test from issue #40 *)
-      Test.make ~name:"int_stats_neg"                  ~count:5000   (add_stat dist small_signed_int)                 (fun _ -> true);
+      Test.make ~name:"int_stats_neg"                  ~count:5000   (add_stat dist int_small)                        (fun _ -> true);
       (* distribution tests from PR #45 *)
-      Test.make ~name:"small_signed_int dist"          ~count:1000   (add_stat dist small_signed_int)                 (fun _ -> true);
-      Test.make ~name:"small_nat dist"                 ~count:1000   (add_stat dist small_nat)                        (fun _ -> true);
-      Test.make ~name:"nat dist"                       ~count:1000   (add_stat dist (make Gen.nat))                   (fun _ -> true);
+      Test.make ~name:"int dist"                       ~count:100000 (add_stat dist int)                              (fun _ -> true);
+      Test.make ~name:"int_bound 1000 dist"            ~count:10000  (add_stat dist (int_bound 1000))                 (fun _ -> true);
       Test.make ~name:"int_range (-43643) 435434 dist" ~count:1000   (add_stat dist (int_range (-43643) 435434))      (fun _ -> true);
       Test.make ~name:"int_range (-40000) 40000 dist"  ~count:1000   (add_stat dist (int_range (-40000) 40000))       (fun _ -> true);
       Test.make ~name:"int_range (-4) 4 dist"          ~count:1000   (add_stat dist (int_range (-4) 4))               (fun _ -> true);
       Test.make ~name:"int_range (-4) 17 dist"         ~count:1000   (add_stat dist (int_range (-4) 17))              (fun _ -> true);
-      Test.make ~name:"int dist"                       ~count:100000 (add_stat dist int)                              (fun _ -> true);
-      Test.make ~name:"oneof int dist"                 ~count:1000   (add_stat dist (oneofl[min_int;-1;0;1;max_int])) (fun _ -> true);
+      Test.make ~name:"int_small dist"                 ~count:1000   (add_stat dist int_small)                        (fun _ -> true);
+      Test.make ~name:"int_small_corners dist"         ~count:1000   (add_stat dist (int_small_corners ()))           (fun _ -> true);
+      Test.make ~name:"int_neg dist"                   ~count:10000  (add_stat dist int_neg)                          (fun _ -> true);
+      Test.make ~name:"int_pos dist"                   ~count:10000  (add_stat dist int_pos)                          (fun _ -> true);
+      Test.make ~name:"oneof_list int dist"            ~count:1000   (add_stat dist (oneof_list[min_int;-1;0;1;max_int])) (fun _ -> true);
+      Test.make ~name:"nat dist"                       ~count:1000   (add_stat dist nat)                              (fun _ -> true);
+      Test.make ~name:"nat_small dist"                 ~count:1000   (add_stat dist nat_small)                        (fun _ -> true);
     ]
 
   let int_32_64_dist_tests =
@@ -1225,10 +1232,10 @@ module Stats = struct
       Test.make ~name:"int64 upper dist"     ~count:10000 (add_stat64 (fun i -> Int64.shift_right_logical i 48) int64) (fun _ -> true);
     ]
 
-  let exponential_tests =
+  let float_exp_tests =
     let float_dist = ("dist",int_of_float) in
-    [ Test.make ~name:"exponential 10. dist" ~count:5_000 (add_stat float_dist (exponential 10.)) (fun _ -> true);
-      Test.make ~name:"exponential -10. dist" ~count:5_000 (add_stat float_dist (exponential (-10.))) (fun _ -> true);
+    [ Test.make ~name:"float_exp 10. dist" ~count:5_000 (add_stat float_dist (float_exp 10.)) (fun _ -> true);
+      Test.make ~name:"float_exp -10. dist" ~count:5_000 (add_stat float_dist (float_exp (-10.))) (fun _ -> true);
     ]
 
   let float_tests = (* Float.frexp nan (and infinity) is undefined and may return a 32766 exponent on Alpine *)
@@ -1257,13 +1264,13 @@ module Stats = struct
 
   let int_dist_empty_bucket =
     Test.make ~name:"int_dist_empty_bucket" ~count:1_000
-      (add_stat ("dist",fun x -> x) (oneof [small_int_corners ();int])) (fun _ -> true)
+      (add_stat ("dist",fun x -> x) (oneof [int_small_corners ();int])) (fun _ -> true)
 
   let tests =
     [ bool_dist; ]
     @ char_dist_tests
     @ [tree_depth_test;
-       range_subset_test;]
+       range_subset_test;] (* Feature (and tests) only available in QCheck for now, not QCheck2 *)
     @ bytes_len_tests
     @ string_len_tests
     @ [pair_dist;
@@ -1276,6 +1283,6 @@ module Stats = struct
     @ array_len_tests
     @ int_dist_tests
     @ int_32_64_dist_tests
-    @ exponential_tests
+    @ float_exp_tests
     @ float_tests
 end
